# This file was auto-generated by Fern from our API Definition.

import typing

from .allowed_output_formats import AllowedOutputFormats
from .music_only_output_formats import MusicOnlyOutputFormats

MusicAllowedOutputFormats = typing.Union[AllowedOutputFormats, MusicOnlyOutputFormats]
