# This file was auto-generated by Fern from our API Definition.

import typing

VoiceDesignRequestModelModelId = typing.Union[typing.Literal["eleven_multilingual_ttv_v2", "eleven_ttv_v3"], typing.Any]
