# This file was auto-generated by Fern from our API Definition.

import typing

BatchCallStatus = typing.Union[typing.Literal["pending", "in_progress", "completed", "failed", "cancelled"], typing.Any]
