# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .agent_platform_settings_request_model import AgentPlatformSettingsRequestModel
from .agent_workflow_request_model import AgentWorkflowRequestModel
from .conversational_config import ConversationalConfig


class AdhocAgentConfigOverrideForTestRequestModel(UncheckedBaseModel):
    conversation_config: ConversationalConfig
    platform_settings: AgentPlatformSettingsRequestModel
    workflow: typing.Optional[AgentWorkflowRequestModel] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(AdhocAgentConfigOverrideForTestRequestModel)
