# This file was auto-generated by Fern from our API Definition.

import typing

EmbeddingModelEnum = typing.Union[
    typing.Literal["e5_mistral_7b_instruct", "multilingual_e5_large_instruct"], typing.Any
]
