# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel


class WorkflowToolResponseModelInput(UncheckedBaseModel):
    """
    A common model for workflow tool responses.
    """

    steps: typing.Optional[typing.List["WorkflowToolResponseModelInputStepsItem"]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .workflow_tool_response_model_input_steps_item import WorkflowToolResponseModelInputStepsItem  # noqa: E402, I001

update_forward_refs(WorkflowToolResponseModelInput)
