# This file was auto-generated by Fern from our API Definition.

import typing

BodyEditServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysApiKeyIdPatchAllowedIps = typing.Union[
    typing.List[str], typing.Literal["clear"], typing.Literal["no_update"]
]
