# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.audio_output_multi import AudioOutputMulti
from ...types.final_output_multi import FinalOutputMulti

ReceiveMessageMulti = typing.Union[AudioOutputMulti, FinalOutputMulti]
