# This file was auto-generated by Fern from our API Definition.

import typing

from .conversation_source import ConversationSource
from .manual_source import ManualSource

MemoryEntrySearchResultSource = typing.Union[ConversationSource, ManualSource]
