# This file was auto-generated by Fern from our API Definition.

import typing

BackgroundSoundPresetId = typing.Union[
    typing.Literal[
        "office2", "office1", "restaurant", "city", "typing", "elevator1", "elevator2", "elevator3", "elevator4"
    ],
    typing.Any,
]
