# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property_output_constant_value_item import ArrayJsonSchemaPropertyOutputConstantValueItem


class ArrayJsonSchemaPropertyOutput(UncheckedBaseModel):
    type: typing.Optional[typing.Literal["array"]] = None
    description: typing.Optional[str] = None
    items: typing.Optional["ArrayJsonSchemaPropertyOutputItems"] = pydantic.Field(default=None)
    """
    Schema for array elements.
    """

    dynamic_variable: typing.Optional[str] = pydantic.Field(default=None)
    """
    When set, the entire array is populated from this dynamic variable at runtime. Mutually exclusive with description (LLM-provided array), constant_value, and is_omitted.
    """

    constant_value: typing.Optional[typing.List[ArrayJsonSchemaPropertyOutputConstantValueItem]] = pydantic.Field(
        default=None
    )
    """
    When set, the entire array uses this constant value at runtime. Mutually exclusive with description (LLM-provided array), dynamic_variable, and is_omitted.
    """

    is_omitted: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, this array parameter will be completely omitted from the request. Only valid for optional parameters. Mutually exclusive with description, dynamic_variable, and constant_value.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput  # noqa: E402, I001
from .array_json_schema_property_output_items import ArrayJsonSchemaPropertyOutputItems  # noqa: E402, I001

update_forward_refs(ArrayJsonSchemaPropertyOutput, ObjectJsonSchemaPropertyOutput=ObjectJsonSchemaPropertyOutput)
