# This file was auto-generated by Fern from our API Definition.

import typing

InvoiceResponseModelPaymentIntentStatus = typing.Union[
    typing.Literal[
        "canceled",
        "processing",
        "requires_action",
        "requires_capture",
        "requires_confirmation",
        "requires_payment_method",
        "succeeded",
    ],
    typing.Any,
]
