# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class ProjectVoiceResponseModel(UncheckedBaseModel):
    project_voice_ref_id: str
    voice_id: str
    alias: str
    stability: float
    similarity_boost: float
    style: float
    is_pinned: bool
    use_speaker_boost: bool
    volume_gain: float
    speed: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
