# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.request_options import RequestOptions
from ....types.column_filter import ColumnFilter
from ....types.workspace_analytics_query_response_model import WorkspaceAnalyticsQueryResponseModel
from .raw_client import AsyncRawRequestsClient, RawRequestsClient
from .types.body_list_api_requests_v_1_workspace_analytics_requests_post_sort import (
    BodyListApiRequestsV1WorkspaceAnalyticsRequestsPostSort,
)

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RequestsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawRequestsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawRequestsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawRequestsClient
        """
        return self._raw_client

    def get(
        self,
        *,
        start_time: typing.Optional[int] = OMIT,
        end_time: typing.Optional[int] = OMIT,
        limit: typing.Optional[int] = OMIT,
        sort: typing.Optional[BodyListApiRequestsV1WorkspaceAnalyticsRequestsPostSort] = OMIT,
        filters: typing.Optional[typing.Sequence[ColumnFilter]] = OMIT,
        search: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WorkspaceAnalyticsQueryResponseModel:
        """
        Returns a list of API requests. Supports filtering by time range, column filters, and search terms. At least one of start_time or end_time must be provided. An optional sort parameter controls timestamp ordering. Results are ordered by timestamp. Descending if end_time is used, ascending if start_time is used. The response is a tabular structure with columns, column_types, column_units, and rows.

        Parameters
        ----------
        start_time : typing.Optional[int]
            Start of the time range as a Unix timestamp in milliseconds.

        end_time : typing.Optional[int]
            End of the time range as a Unix timestamp in milliseconds.

        limit : typing.Optional[int]

        sort : typing.Optional[BodyListApiRequestsV1WorkspaceAnalyticsRequestsPostSort]
            Optional timestamp sort direction. If omitted, defaults to desc when end_time is provided, otherwise asc.

        filters : typing.Optional[typing.Sequence[ColumnFilter]]

        search : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceAnalyticsQueryResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.analytics.requests.get()
        """
        _response = self._raw_client.get(
            start_time=start_time,
            end_time=end_time,
            limit=limit,
            sort=sort,
            filters=filters,
            search=search,
            request_options=request_options,
        )
        return _response.data


class AsyncRequestsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawRequestsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawRequestsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawRequestsClient
        """
        return self._raw_client

    async def get(
        self,
        *,
        start_time: typing.Optional[int] = OMIT,
        end_time: typing.Optional[int] = OMIT,
        limit: typing.Optional[int] = OMIT,
        sort: typing.Optional[BodyListApiRequestsV1WorkspaceAnalyticsRequestsPostSort] = OMIT,
        filters: typing.Optional[typing.Sequence[ColumnFilter]] = OMIT,
        search: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WorkspaceAnalyticsQueryResponseModel:
        """
        Returns a list of API requests. Supports filtering by time range, column filters, and search terms. At least one of start_time or end_time must be provided. An optional sort parameter controls timestamp ordering. Results are ordered by timestamp. Descending if end_time is used, ascending if start_time is used. The response is a tabular structure with columns, column_types, column_units, and rows.

        Parameters
        ----------
        start_time : typing.Optional[int]
            Start of the time range as a Unix timestamp in milliseconds.

        end_time : typing.Optional[int]
            End of the time range as a Unix timestamp in milliseconds.

        limit : typing.Optional[int]

        sort : typing.Optional[BodyListApiRequestsV1WorkspaceAnalyticsRequestsPostSort]
            Optional timestamp sort direction. If omitted, defaults to desc when end_time is provided, otherwise asc.

        filters : typing.Optional[typing.Sequence[ColumnFilter]]

        search : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceAnalyticsQueryResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.analytics.requests.get()


        asyncio.run(main())
        """
        _response = await self._raw_client.get(
            start_time=start_time,
            end_time=end_time,
            limit=limit,
            sort=sort,
            filters=filters,
            search=search,
            request_options=request_options,
        )
        return _response.data
