# This file was auto-generated by Fern from our API Definition.

import typing

RagIndexStatus = typing.Union[
    typing.Literal[
        "new",
        "created",
        "processing",
        "failed",
        "succeeded",
        "rag_limit_exceeded",
        "document_too_small",
        "cannot_index_folder",
    ],
    typing.Any,
]
