# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .llm_literal_json_schema_property import LlmLiteralJsonSchemaProperty


class AstllmNodeOutput(UncheckedBaseModel):
    value_schema: LlmLiteralJsonSchemaProperty = pydantic.Field()
    """
    JSON schema describing the value that the LLM should extract.
    """

    prompt: str = pydantic.Field()
    """
    The prompt to evaluate to a boolean value. Deprecated. Use a boolean schema instead.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
