# This file was auto-generated by Fern from our API Definition.

import typing

DirectPublishingReadResponseModelPayoutType = typing.Union[
    typing.Literal["none", "engagement_based", "fixed_payout"], typing.Any
]
