# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.agent_call_limits import AgentCallLimits
from ..types.agent_sort_by import AgentSortBy
from ..types.asr_conversational_config import AsrConversationalConfig
from ..types.base_turn_config import BaseTurnConfig
from ..types.conversation_config_input import ConversationConfigInput
from ..types.list_speech_engines_response import ListSpeechEnginesResponse
from ..types.privacy_config_input import PrivacyConfigInput
from ..types.sort_direction import SortDirection
from ..types.speech_engine_config import SpeechEngineConfig
from ..types.speech_engine_conversation_initiation_client_data_config import SpeechEngineConversationInitiationClientDataConfig
from ..types.speech_engine_response import SpeechEngineResponse
from ..types.tts_conversational_config_input import TtsConversationalConfigInput

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawSpeechEngineClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        page_size: typing.Optional[int] = None,
        search: typing.Optional[str] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        sort_by: typing.Optional[AgentSortBy] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ListSpeechEnginesResponse]:
        """
        Returns a paginated list of Speech Engine resources.

        Parameters
        ----------
        page_size : typing.Optional[int]
            How many Speech Engines to return at maximum. Can not exceed 100, defaults to 30.

        search : typing.Optional[str]
            Search term to filter Speech Engines by name

        sort_direction : typing.Optional[SortDirection]
            The direction to sort the results

        sort_by : typing.Optional[AgentSortBy]
            The field to sort the results by

        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ListSpeechEnginesResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/speech-engine",
            method="GET",
            params={
                "page_size": page_size,
                "search": search,
                "sort_direction": sort_direction,
                "sort_by": sort_by,
                "cursor": cursor,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListSpeechEnginesResponse,
                    construct_type(
                        type_=ListSpeechEnginesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        *,
        speech_engine: SpeechEngineConfig,
        name: typing.Optional[str] = OMIT,
        asr: typing.Optional[AsrConversationalConfig] = OMIT,
        tts: typing.Optional[TtsConversationalConfigInput] = OMIT,
        turn: typing.Optional[BaseTurnConfig] = OMIT,
        conversation: typing.Optional[ConversationConfigInput] = OMIT,
        privacy: typing.Optional[PrivacyConfigInput] = OMIT,
        call_limits: typing.Optional[AgentCallLimits] = OMIT,
        language: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        overrides: typing.Optional[SpeechEngineConversationInitiationClientDataConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SpeechEngineResponse]:
        """
        Create a new Speech Engine resource

        Parameters
        ----------
        speech_engine : SpeechEngineConfig
            Speech engine WebSocket configuration

        name : typing.Optional[str]
            Name of the speech engine

        asr : typing.Optional[AsrConversationalConfig]
            ASR configuration

        tts : typing.Optional[TtsConversationalConfigInput]
            TTS configuration

        turn : typing.Optional[BaseTurnConfig]
            Turn detection configuration

        conversation : typing.Optional[ConversationConfigInput]
            Conversation configuration (client events, etc.)

        privacy : typing.Optional[PrivacyConfigInput]
            Privacy settings (recording, retention, zero retention mode)

        call_limits : typing.Optional[AgentCallLimits]
            Concurrency and daily conversation limits for this speech engine

        language : typing.Optional[str]
            Language for the speech engine

        tags : typing.Optional[typing.Sequence[str]]
            Tags for categorization

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SpeechEngineResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/speech-engine",
            method="POST",
            json={
                "name": name,
                "speech_engine": convert_and_respect_annotation_metadata(
                    object_=speech_engine, annotation=SpeechEngineConfig, direction="write"
                ),
                "asr": convert_and_respect_annotation_metadata(
                    object_=asr, annotation=AsrConversationalConfig, direction="write"
                ),
                "tts": convert_and_respect_annotation_metadata(
                    object_=tts, annotation=TtsConversationalConfigInput, direction="write"
                ),
                "turn": convert_and_respect_annotation_metadata(
                    object_=turn, annotation=BaseTurnConfig, direction="write"
                ),
                "conversation": convert_and_respect_annotation_metadata(
                    object_=conversation, annotation=ConversationConfigInput, direction="write"
                ),
                "privacy": convert_and_respect_annotation_metadata(
                    object_=privacy, annotation=PrivacyConfigInput, direction="write"
                ),
                "call_limits": convert_and_respect_annotation_metadata(
                    object_=call_limits, annotation=AgentCallLimits, direction="write"
                ),
                "language": language,
                "tags": tags,
                "overrides": convert_and_respect_annotation_metadata(
                    object_=overrides, annotation=SpeechEngineConversationInitiationClientDataConfig, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SpeechEngineResponse,
                    construct_type(
                        type_=SpeechEngineResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, speech_engine_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SpeechEngineResponse]:
        """
        Retrieve a Speech Engine resource

        Parameters
        ----------
        speech_engine_id : str
            The speech engine ID (accepts seng_ or agent_ prefix)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SpeechEngineResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/speech-engine/{jsonable_encoder(speech_engine_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SpeechEngineResponse,
                    construct_type(
                        type_=SpeechEngineResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, speech_engine_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[None]:
        """
        Delete a Speech Engine resource

        Parameters
        ----------
        speech_engine_id : str
            The speech engine ID (accepts seng_ or agent_ prefix)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/speech-engine/{jsonable_encoder(speech_engine_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        speech_engine_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        speech_engine: typing.Optional[SpeechEngineConfig] = OMIT,
        asr: typing.Optional[AsrConversationalConfig] = OMIT,
        tts: typing.Optional[TtsConversationalConfigInput] = OMIT,
        turn: typing.Optional[BaseTurnConfig] = OMIT,
        conversation: typing.Optional[ConversationConfigInput] = OMIT,
        privacy: typing.Optional[PrivacyConfigInput] = OMIT,
        call_limits: typing.Optional[AgentCallLimits] = OMIT,
        language: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SpeechEngineResponse]:
        """
        Update a Speech Engine resource (partial update)

        Parameters
        ----------
        speech_engine_id : str
            The speech engine ID (accepts seng_ or agent_ prefix)

        name : typing.Optional[str]

        speech_engine : typing.Optional[SpeechEngineConfig]

        asr : typing.Optional[AsrConversationalConfig]

        tts : typing.Optional[TtsConversationalConfigInput]

        turn : typing.Optional[BaseTurnConfig]

        conversation : typing.Optional[ConversationConfigInput]

        privacy : typing.Optional[PrivacyConfigInput]

        call_limits : typing.Optional[AgentCallLimits]

        language : typing.Optional[str]

        tags : typing.Optional[typing.Sequence[str]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SpeechEngineResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/speech-engine/{jsonable_encoder(speech_engine_id)}",
            method="PATCH",
            json={
                "name": name,
                "speech_engine": convert_and_respect_annotation_metadata(
                    object_=speech_engine, annotation=SpeechEngineConfig, direction="write"
                ),
                "asr": convert_and_respect_annotation_metadata(
                    object_=asr, annotation=AsrConversationalConfig, direction="write"
                ),
                "tts": convert_and_respect_annotation_metadata(
                    object_=tts, annotation=TtsConversationalConfigInput, direction="write"
                ),
                "turn": convert_and_respect_annotation_metadata(
                    object_=turn, annotation=BaseTurnConfig, direction="write"
                ),
                "conversation": convert_and_respect_annotation_metadata(
                    object_=conversation, annotation=ConversationConfigInput, direction="write"
                ),
                "privacy": convert_and_respect_annotation_metadata(
                    object_=privacy, annotation=PrivacyConfigInput, direction="write"
                ),
                "call_limits": convert_and_respect_annotation_metadata(
                    object_=call_limits, annotation=AgentCallLimits, direction="write"
                ),
                "language": language,
                "tags": tags,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SpeechEngineResponse,
                    construct_type(
                        type_=SpeechEngineResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawSpeechEngineClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        page_size: typing.Optional[int] = None,
        search: typing.Optional[str] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        sort_by: typing.Optional[AgentSortBy] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ListSpeechEnginesResponse]:
        """
        Returns a paginated list of Speech Engine resources.

        Parameters
        ----------
        page_size : typing.Optional[int]
            How many Speech Engines to return at maximum. Can not exceed 100, defaults to 30.

        search : typing.Optional[str]
            Search term to filter Speech Engines by name

        sort_direction : typing.Optional[SortDirection]
            The direction to sort the results

        sort_by : typing.Optional[AgentSortBy]
            The field to sort the results by

        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ListSpeechEnginesResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/speech-engine",
            method="GET",
            params={
                "page_size": page_size,
                "search": search,
                "sort_direction": sort_direction,
                "sort_by": sort_by,
                "cursor": cursor,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListSpeechEnginesResponse,
                    construct_type(
                        type_=ListSpeechEnginesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        *,
        speech_engine: SpeechEngineConfig,
        name: typing.Optional[str] = OMIT,
        asr: typing.Optional[AsrConversationalConfig] = OMIT,
        tts: typing.Optional[TtsConversationalConfigInput] = OMIT,
        turn: typing.Optional[BaseTurnConfig] = OMIT,
        conversation: typing.Optional[ConversationConfigInput] = OMIT,
        privacy: typing.Optional[PrivacyConfigInput] = OMIT,
        call_limits: typing.Optional[AgentCallLimits] = OMIT,
        language: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        overrides: typing.Optional[SpeechEngineConversationInitiationClientDataConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SpeechEngineResponse]:
        """
        Create a new Speech Engine resource

        Parameters
        ----------
        speech_engine : SpeechEngineConfig
            Speech engine WebSocket configuration

        name : typing.Optional[str]
            Name of the speech engine

        asr : typing.Optional[AsrConversationalConfig]
            ASR configuration

        tts : typing.Optional[TtsConversationalConfigInput]
            TTS configuration

        turn : typing.Optional[BaseTurnConfig]
            Turn detection configuration

        conversation : typing.Optional[ConversationConfigInput]
            Conversation configuration (client events, etc.)

        privacy : typing.Optional[PrivacyConfigInput]
            Privacy settings (recording, retention, zero retention mode)

        call_limits : typing.Optional[AgentCallLimits]
            Concurrency and daily conversation limits for this speech engine

        language : typing.Optional[str]
            Language for the speech engine

        tags : typing.Optional[typing.Sequence[str]]
            Tags for categorization

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SpeechEngineResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/speech-engine",
            method="POST",
            json={
                "name": name,
                "speech_engine": convert_and_respect_annotation_metadata(
                    object_=speech_engine, annotation=SpeechEngineConfig, direction="write"
                ),
                "asr": convert_and_respect_annotation_metadata(
                    object_=asr, annotation=AsrConversationalConfig, direction="write"
                ),
                "tts": convert_and_respect_annotation_metadata(
                    object_=tts, annotation=TtsConversationalConfigInput, direction="write"
                ),
                "turn": convert_and_respect_annotation_metadata(
                    object_=turn, annotation=BaseTurnConfig, direction="write"
                ),
                "conversation": convert_and_respect_annotation_metadata(
                    object_=conversation, annotation=ConversationConfigInput, direction="write"
                ),
                "privacy": convert_and_respect_annotation_metadata(
                    object_=privacy, annotation=PrivacyConfigInput, direction="write"
                ),
                "call_limits": convert_and_respect_annotation_metadata(
                    object_=call_limits, annotation=AgentCallLimits, direction="write"
                ),
                "language": language,
                "tags": tags,
                "overrides": convert_and_respect_annotation_metadata(
                    object_=overrides, annotation=SpeechEngineConversationInitiationClientDataConfig, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SpeechEngineResponse,
                    construct_type(
                        type_=SpeechEngineResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, speech_engine_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SpeechEngineResponse]:
        """
        Retrieve a Speech Engine resource

        Parameters
        ----------
        speech_engine_id : str
            The speech engine ID (accepts seng_ or agent_ prefix)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SpeechEngineResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/speech-engine/{jsonable_encoder(speech_engine_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SpeechEngineResponse,
                    construct_type(
                        type_=SpeechEngineResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, speech_engine_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[None]:
        """
        Delete a Speech Engine resource

        Parameters
        ----------
        speech_engine_id : str
            The speech engine ID (accepts seng_ or agent_ prefix)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/speech-engine/{jsonable_encoder(speech_engine_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        speech_engine_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        speech_engine: typing.Optional[SpeechEngineConfig] = OMIT,
        asr: typing.Optional[AsrConversationalConfig] = OMIT,
        tts: typing.Optional[TtsConversationalConfigInput] = OMIT,
        turn: typing.Optional[BaseTurnConfig] = OMIT,
        conversation: typing.Optional[ConversationConfigInput] = OMIT,
        privacy: typing.Optional[PrivacyConfigInput] = OMIT,
        call_limits: typing.Optional[AgentCallLimits] = OMIT,
        language: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SpeechEngineResponse]:
        """
        Update a Speech Engine resource (partial update)

        Parameters
        ----------
        speech_engine_id : str
            The speech engine ID (accepts seng_ or agent_ prefix)

        name : typing.Optional[str]

        speech_engine : typing.Optional[SpeechEngineConfig]

        asr : typing.Optional[AsrConversationalConfig]

        tts : typing.Optional[TtsConversationalConfigInput]

        turn : typing.Optional[BaseTurnConfig]

        conversation : typing.Optional[ConversationConfigInput]

        privacy : typing.Optional[PrivacyConfigInput]

        call_limits : typing.Optional[AgentCallLimits]

        language : typing.Optional[str]

        tags : typing.Optional[typing.Sequence[str]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SpeechEngineResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/speech-engine/{jsonable_encoder(speech_engine_id)}",
            method="PATCH",
            json={
                "name": name,
                "speech_engine": convert_and_respect_annotation_metadata(
                    object_=speech_engine, annotation=SpeechEngineConfig, direction="write"
                ),
                "asr": convert_and_respect_annotation_metadata(
                    object_=asr, annotation=AsrConversationalConfig, direction="write"
                ),
                "tts": convert_and_respect_annotation_metadata(
                    object_=tts, annotation=TtsConversationalConfigInput, direction="write"
                ),
                "turn": convert_and_respect_annotation_metadata(
                    object_=turn, annotation=BaseTurnConfig, direction="write"
                ),
                "conversation": convert_and_respect_annotation_metadata(
                    object_=conversation, annotation=ConversationConfigInput, direction="write"
                ),
                "privacy": convert_and_respect_annotation_metadata(
                    object_=privacy, annotation=PrivacyConfigInput, direction="write"
                ),
                "call_limits": convert_and_respect_annotation_metadata(
                    object_=call_limits, annotation=AgentCallLimits, direction="write"
                ),
                "language": language,
                "tags": tags,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SpeechEngineResponse,
                    construct_type(
                        type_=SpeechEngineResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
