# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .sip_log_message_direction import SipLogMessageDirection


class SipLogMessage(UncheckedBaseModel):
    call_id: str
    phone_numbers: typing.List[str]
    local_address: str
    remote_address: str
    transport: str
    raw_message: str
    error_message: str
    direction: SipLogMessageDirection
    created_at_unix_micro: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
