# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .dependent_available_agent_identifier_access_level import DependentAvailableAgentIdentifierAccessLevel


class DependentAvailableAgentIdentifier(UncheckedBaseModel):
    referenced_resource_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    If the agent is a transitive dependent, contains IDs of the resources that the agent depends on directly.
    """

    id: str
    name: str
    created_at_unix_secs: int
    access_level: DependentAvailableAgentIdentifierAccessLevel

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
