# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.permission_type import PermissionType

BodyEditServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysApiKeyIdPatchPermissions = typing.Union[
    typing.List[PermissionType], typing.Literal["all"], typing.Literal["no_update"]
]
