# This file was auto-generated by Fern from our API Definition.

import typing

ConversationSentimentAnalysisOverallLabel = typing.Union[typing.Literal["positive", "neutral", "negative"], typing.Any]
