# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .body_create_podcast_v_1_studio_podcasts_post_apply_text_normalization import (
        BodyCreatePodcastV1StudioPodcastsPostApplyTextNormalization,
    )
    from .body_create_podcast_v_1_studio_podcasts_post_duration_scale import (
        BodyCreatePodcastV1StudioPodcastsPostDurationScale,
    )
    from .body_create_podcast_v_1_studio_podcasts_post_mode import (
        BodyCreatePodcastV1StudioPodcastsPostMode,
        BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin,
        BodyCreatePodcastV1StudioPodcastsPostMode_Conversation,
    )
    from .body_create_podcast_v_1_studio_podcasts_post_source import BodyCreatePodcastV1StudioPodcastsPostSource
    from .body_create_podcast_v_1_studio_podcasts_post_source_two_item import (
        BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem,
        BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Text,
        BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Url,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BodyCreatePodcastV1StudioPodcastsPostApplyTextNormalization": ".body_create_podcast_v_1_studio_podcasts_post_apply_text_normalization",
    "BodyCreatePodcastV1StudioPodcastsPostDurationScale": ".body_create_podcast_v_1_studio_podcasts_post_duration_scale",
    "BodyCreatePodcastV1StudioPodcastsPostMode": ".body_create_podcast_v_1_studio_podcasts_post_mode",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin": ".body_create_podcast_v_1_studio_podcasts_post_mode",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Conversation": ".body_create_podcast_v_1_studio_podcasts_post_mode",
    "BodyCreatePodcastV1StudioPodcastsPostSource": ".body_create_podcast_v_1_studio_podcasts_post_source",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem": ".body_create_podcast_v_1_studio_podcasts_post_source_two_item",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Text": ".body_create_podcast_v_1_studio_podcasts_post_source_two_item",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Url": ".body_create_podcast_v_1_studio_podcasts_post_source_two_item",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BodyCreatePodcastV1StudioPodcastsPostApplyTextNormalization",
    "BodyCreatePodcastV1StudioPodcastsPostDurationScale",
    "BodyCreatePodcastV1StudioPodcastsPostMode",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Conversation",
    "BodyCreatePodcastV1StudioPodcastsPostSource",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Text",
    "BodyCreatePodcastV1StudioPodcastsPostSourceTwoItem_Url",
]
