# This file was auto-generated by Fern from our API Definition.

import typing

ReferencedToolCommonModelType = typing.Union[
    typing.Literal["system", "webhook", "client", "workflow", "api_integration_webhook", "mcp", "code"], typing.Any
]
