# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

WorkspaceAnalyticsQueryResponseModelRowsItemItem = typing.Union[str, int, float, bool, dt.datetime]
