# This file was auto-generated by Fern from our API Definition.

import typing

LockReason = typing.Union[
    typing.Literal["trial_ended", "subscription_downgrade", "exposed_publicly", "self_disabled"], typing.Any
]
