# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .song_section import SongSection


class MusicPrompt(UncheckedBaseModel):
    """
    Composition plan for the `music_v1` model. Using this field with any other model will result in an error.
    """

    positive_global_styles: typing.List[str] = pydantic.Field()
    """
    The styles and musical directions that should be present in the entire song. Use English language for best result.
    """

    negative_global_styles: typing.List[str] = pydantic.Field()
    """
    The styles and musical directions that should not be present in the entire song. Use English language for best result.
    """

    sections: typing.List[SongSection] = pydantic.Field()
    """
    The sections of the song.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
