# This file was auto-generated by Fern from our API Definition.

import typing

DirectPublishingReadResponseModelGenreItem = typing.Union[
    typing.Literal[
        "Fantasy",
        "Romance",
        "Science Fiction",
        "Mystery and Thriller",
        "Action and Adventure",
        "Dystopia",
        "Business and Economics",
        "Technology",
        "Christian & Inspirational",
        "Horror",
        "Biography and Memoir",
        "Education and Learning",
        "History",
        "Children's Literature",
        "Young Adult",
        "Fairy Tales and Folklore",
        "Fan Fiction",
        "General Fiction",
        "Health and Wellness",
        "Historical Fiction",
        "Humor",
        "Literary Classics",
        "Philosophy",
        "Poetry",
        "Politics and Government",
        "Psychology",
        "Science and Nature",
        "Self-Help",
        "Spirituality and Religion",
        "Travel",
        "True Crime",
        "Other",
    ],
    typing.Any,
]
