# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .document_refresh_response import (
        DocumentRefreshResponse,
        DocumentRefreshResponse_File,
        DocumentRefreshResponse_Folder,
        DocumentRefreshResponse_Text,
        DocumentRefreshResponse_Url,
    )
    from .document_update_file_response import (
        DocumentUpdateFileResponse,
        DocumentUpdateFileResponse_File,
        DocumentUpdateFileResponse_Folder,
        DocumentUpdateFileResponse_Text,
        DocumentUpdateFileResponse_Url,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "DocumentRefreshResponse": ".document_refresh_response",
    "DocumentRefreshResponse_File": ".document_refresh_response",
    "DocumentRefreshResponse_Folder": ".document_refresh_response",
    "DocumentRefreshResponse_Text": ".document_refresh_response",
    "DocumentRefreshResponse_Url": ".document_refresh_response",
    "DocumentUpdateFileResponse": ".document_update_file_response",
    "DocumentUpdateFileResponse_File": ".document_update_file_response",
    "DocumentUpdateFileResponse_Folder": ".document_update_file_response",
    "DocumentUpdateFileResponse_Text": ".document_update_file_response",
    "DocumentUpdateFileResponse_Url": ".document_update_file_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "DocumentRefreshResponse",
    "DocumentRefreshResponse_File",
    "DocumentRefreshResponse_Folder",
    "DocumentRefreshResponse_Text",
    "DocumentRefreshResponse_Url",
    "DocumentUpdateFileResponse",
    "DocumentUpdateFileResponse_File",
    "DocumentUpdateFileResponse_Folder",
    "DocumentUpdateFileResponse_Text",
    "DocumentUpdateFileResponse_Url",
]
