# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .conversation_asr_usage_model import ConversationAsrUsageModel
from .conversation_tts_usage_model import ConversationTtsUsageModel
from .llm_category_usage import LlmCategoryUsage


class ConversationChargingCommonModel(UncheckedBaseModel):
    dev_discount: typing.Optional[bool] = None
    is_burst: typing.Optional[bool] = None
    tier: typing.Optional[str] = None
    llm_usage: typing.Optional[LlmCategoryUsage] = None
    llm_price: typing.Optional[float] = None
    llm_charge: typing.Optional[int] = None
    call_charge: typing.Optional[int] = None
    free_minutes_consumed: typing.Optional[float] = None
    free_llm_dollars_consumed: typing.Optional[float] = None
    tts_usage: typing.Optional[ConversationTtsUsageModel] = None
    asr_usage: typing.Optional[ConversationAsrUsageModel] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
