# This file was auto-generated by Fern from our API Definition.

import typing

BodyEditServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysApiKeyIdPatchIsEnabled = typing.Union[
    bool, typing.Literal["no_update"]
]
