# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .clip_animation_enter_effect import ClipAnimationEnterEffect
from .clip_animation_exit_effect import ClipAnimationExitEffect


class ClipAnimation(UncheckedBaseModel):
    enter_effect: typing.Optional[ClipAnimationEnterEffect] = None
    enter_duration_ms: typing.Optional[int] = None
    exit_effect: typing.Optional[ClipAnimationExitEffect] = None
    exit_duration_ms: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
