# This file was auto-generated by Fern from our API Definition.

import typing

ColumnUnit = typing.Union[
    typing.Literal["ms", "s", "min", "duration", "credits", "usd", "eur", "inr", "pln", "ratio", "rating"], typing.Any
]
