# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.close_payload import ClosePayload
from ...types.error_payload import ErrorPayload
from ...types.init_payload import InitPayload
from ...types.ping_payload import PingPayload
from ...types.user_transcript_payload import UserTranscriptPayload

ReceiveUpstreamMessage = typing.Union[InitPayload, UserTranscriptPayload, PingPayload, ClosePayload, ErrorPayload]
