# This file was auto-generated by Fern from our API Definition.

import typing

WorkspaceAnalyticsQueryResponseModelColumnTypesItem = typing.Union[
    typing.Literal["String", "Float", "DateTime", "Int", "Bool", "JSON", "Map"], typing.Any
]
