# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .agent_workflow_response_model_nodes_value import AgentWorkflowResponseModelNodesValue
from .workflow_edge_model_output import WorkflowEdgeModelOutput


class AgentWorkflowResponseModel(UncheckedBaseModel):
    edges: typing.Dict[str, WorkflowEdgeModelOutput]
    nodes: typing.Dict[str, AgentWorkflowResponseModelNodesValue]
    prevent_subagent_loops: bool = pydantic.Field()
    """
    Whether to prevent loops in the workflow execution.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(AgentWorkflowResponseModel)
