# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class ScribeAuthErrorPayload(UncheckedBaseModel):
    """
    Payload for authentication errors.
    """

    message_type: typing.Literal["auth_error"] = pydantic.Field(default="auth_error")
    """
    The message type identifier.
    """

    error: str = pydantic.Field()
    """
    Authentication error details.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
