# This file was auto-generated by Fern from our API Definition.

import typing

ConversationHistoryTranscriptOtherToolsResultCommonModelType = typing.Union[
    typing.Literal["client", "webhook", "mcp", "code"], typing.Any
]
