# This file was auto-generated by Fern from our API Definition.

import typing

SubscriptionStatusType = typing.Union[
    typing.Literal["trialing", "active", "incomplete", "past_due", "free", "free_disabled"], typing.Any
]
