# This file was auto-generated by Fern from our API Definition.

import typing

ConversationInitiationSource = typing.Union[
    typing.Literal[
        "unknown",
        "android_sdk",
        "node_js_sdk",
        "react_native_sdk",
        "react_sdk",
        "js_sdk",
        "python_sdk",
        "widget",
        "sip_trunk",
        "twilio",
        "exotel",
        "genesys",
        "swift_sdk",
        "whatsapp",
        "twilio_sms",
        "flutter_sdk",
        "zendesk_integration",
        "slack_integration",
        "telegram_integration",
        "intercom_integration",
        "freshdesk_integration",
        "template_preview",
        "genesys_bot_connector",
    ],
    typing.Any,
]
