# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .item_id import ItemId
from .order_item_request_input import OrderItemRequestInput


class UpsertOrderItemRequest(UncheckedBaseModel):
    item: OrderItemRequestInput = pydantic.Field()
    """
    The order item to add or update.
    """

    item_id: typing.Optional[ItemId] = pydantic.Field(default=None)
    """
    The ID of an existing item to update. Omit to create a new item.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
