# This file was auto-generated by Fern from our API Definition.

import typing

ProjectCreationMetaResponseModelStatus = typing.Union[
    typing.Literal["pending", "creating", "finished", "failed"], typing.Any
]
