# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        KnowledgeBaseGetOrCreateRagIndexesResponseValue,
        KnowledgeBaseGetOrCreateRagIndexesResponseValue_Failure,
        KnowledgeBaseGetOrCreateRagIndexesResponseValue_Success,
    )
    from . import document, documents
    from .document import (
        DocumentRefreshResponse,
        DocumentRefreshResponse_File,
        DocumentRefreshResponse_Folder,
        DocumentRefreshResponse_Text,
        DocumentRefreshResponse_Url,
        DocumentUpdateFileResponse,
        DocumentUpdateFileResponse_File,
        DocumentUpdateFileResponse_Folder,
        DocumentUpdateFileResponse_Text,
        DocumentUpdateFileResponse_Url,
    )
    from .documents import (
        DocumentsGetResponse,
        DocumentsGetResponse_File,
        DocumentsGetResponse_Folder,
        DocumentsGetResponse_Text,
        DocumentsGetResponse_Url,
        DocumentsUpdateResponse,
        DocumentsUpdateResponse_File,
        DocumentsUpdateResponse_Folder,
        DocumentsUpdateResponse_Text,
        DocumentsUpdateResponse_Url,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "DocumentRefreshResponse": ".document",
    "DocumentRefreshResponse_File": ".document",
    "DocumentRefreshResponse_Folder": ".document",
    "DocumentRefreshResponse_Text": ".document",
    "DocumentRefreshResponse_Url": ".document",
    "DocumentUpdateFileResponse": ".document",
    "DocumentUpdateFileResponse_File": ".document",
    "DocumentUpdateFileResponse_Folder": ".document",
    "DocumentUpdateFileResponse_Text": ".document",
    "DocumentUpdateFileResponse_Url": ".document",
    "DocumentsGetResponse": ".documents",
    "DocumentsGetResponse_File": ".documents",
    "DocumentsGetResponse_Folder": ".documents",
    "DocumentsGetResponse_Text": ".documents",
    "DocumentsGetResponse_Url": ".documents",
    "DocumentsUpdateResponse": ".documents",
    "DocumentsUpdateResponse_File": ".documents",
    "DocumentsUpdateResponse_Folder": ".documents",
    "DocumentsUpdateResponse_Text": ".documents",
    "DocumentsUpdateResponse_Url": ".documents",
    "KnowledgeBaseGetOrCreateRagIndexesResponseValue": ".types",
    "KnowledgeBaseGetOrCreateRagIndexesResponseValue_Failure": ".types",
    "KnowledgeBaseGetOrCreateRagIndexesResponseValue_Success": ".types",
    "document": ".document",
    "documents": ".documents",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "DocumentRefreshResponse",
    "DocumentRefreshResponse_File",
    "DocumentRefreshResponse_Folder",
    "DocumentRefreshResponse_Text",
    "DocumentRefreshResponse_Url",
    "DocumentUpdateFileResponse",
    "DocumentUpdateFileResponse_File",
    "DocumentUpdateFileResponse_Folder",
    "DocumentUpdateFileResponse_Text",
    "DocumentUpdateFileResponse_Url",
    "DocumentsGetResponse",
    "DocumentsGetResponse_File",
    "DocumentsGetResponse_Folder",
    "DocumentsGetResponse_Text",
    "DocumentsGetResponse_Url",
    "DocumentsUpdateResponse",
    "DocumentsUpdateResponse_File",
    "DocumentsUpdateResponse_Folder",
    "DocumentsUpdateResponse_Text",
    "DocumentsUpdateResponse_Url",
    "KnowledgeBaseGetOrCreateRagIndexesResponseValue",
    "KnowledgeBaseGetOrCreateRagIndexesResponseValue_Failure",
    "KnowledgeBaseGetOrCreateRagIndexesResponseValue_Success",
    "document",
    "documents",
]
