# This file was auto-generated by Fern from our API Definition.

import typing

from .dependent_phone_number_identifier import DependentPhoneNumberIdentifier
from .get_secret_dependencies_response_model_dependencies_one_item import (
    GetSecretDependenciesResponseModelDependenciesOneItem,
)
from .get_secret_dependencies_response_model_dependencies_zero_item import (
    GetSecretDependenciesResponseModelDependenciesZeroItem,
)

GetSecretDependenciesResponseModelDependencies = typing.Union[
    typing.List[GetSecretDependenciesResponseModelDependenciesZeroItem],
    typing.List[GetSecretDependenciesResponseModelDependenciesOneItem],
    typing.List[DependentPhoneNumberIdentifier],
]
