# This file was auto-generated by Fern from our API Definition.

import typing

ConversationSummaryResponseModelStatus = typing.Union[
    typing.Literal["initiated", "in-progress", "processing", "done", "failed"], typing.Any
]
