# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .video_key_moment import VideoKeyMoment
from .video_segment import VideoSegment
from .video_subject import VideoSubject


class VideoAnalysisResult(UncheckedBaseModel):
    title: str
    description: str
    content_type: typing.Optional[str] = None
    overall_pacing: typing.Optional[str] = None
    subjects: typing.Optional[typing.List[VideoSubject]] = None
    segments: typing.Optional[typing.List[VideoSegment]] = None
    key_moments: typing.Optional[typing.List[VideoKeyMoment]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
