# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class InputAudioChunkPayload(UncheckedBaseModel):
    """
    Payload for sending audio chunks from client to server.
    """

    message_type: typing.Literal["input_audio_chunk"] = pydantic.Field(default="input_audio_chunk")
    """
    The message type identifier.
    """

    audio_base_64: str = pydantic.Field()
    """
    Base64-encoded audio data.
    """

    commit: bool = pydantic.Field()
    """
    Whether to commit the transcription after this chunk.
    """

    sample_rate: int = pydantic.Field()
    """
    Sample rate of the audio in Hz.
    """

    previous_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Send text context to the model. Can only be sent alongside the first audio chunk. If sent in a subsequent chunk, an error will be returned.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
