# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from .cue_options_request import CueOptionsRequest
from .media_id import MediaId


class OrderItemRequestOutput_Dub(UncheckedBaseModel):
    kind: typing.Literal["dub"] = "dub"
    media_id: MediaId
    source_language: str
    destination_languages: typing.List[str]
    include_captions: bool
    include_source_captions: bool
    instructions: typing.Optional[str] = None
    captions_sdh: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class OrderItemRequestOutput_Subtitles(UncheckedBaseModel):
    kind: typing.Literal["subtitles"] = "subtitles"
    media_ids: typing.List[MediaId]
    source_language: str
    destination_languages: typing.List[str]
    cue_options: typing.Optional[CueOptionsRequest] = None
    sdh: typing.Optional[bool] = None
    instructions: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


OrderItemRequestOutput = typing_extensions.Annotated[
    typing.Union[OrderItemRequestOutput_Dub, OrderItemRequestOutput_Subtitles], UnionMetadata(discriminant="kind")
]
