# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .conversation_voice_usage_model import ConversationVoiceUsageModel


class ConversationTtsUsageModel(UncheckedBaseModel):
    """
    Aggregated TTS usage for a conversation (analytics-only, not billing).
    """

    primary_tts_model: typing.Optional[str] = None
    total_audio_output_seconds: typing.Optional[float] = None
    total_characters: typing.Optional[int] = None
    per_voice_usage: typing.Optional[typing.List[ConversationVoiceUsageModel]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
