# This file was auto-generated by Fern from our API Definition.

import typing

ContentThresholdGuardrailThreshold = typing.Union[
    float, typing.Literal["low"], typing.Literal["medium"], typing.Literal["high"]
]
