# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.composition_plan import CompositionPlan
from ....types.music_prompt import MusicPrompt

CompositionPlanCreateResponse = typing.Union[MusicPrompt, CompositionPlan]
