# This file was auto-generated by Fern from our API Definition.

import typing

SpeakerSeparationResponseModelStatus = typing.Union[
    typing.Literal["not_started", "pending", "completed", "failed"], typing.Any
]
