# This file was auto-generated by Fern from our API Definition.

import typing

from .composition_plan import CompositionPlan
from .music_prompt import MusicPrompt

DetailedMusicResponseCompositionPlan = typing.Union[MusicPrompt, CompositionPlan]
