# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        McpServerConfigUpdateRequestModelAuthConnection,
        McpServerConfigUpdateRequestModelRequestHeadersValue,
    )
    from . import approval_policy, tool_approvals, tool_configs, tools
    from .tool_configs import (
        McpToolConfigOverrideCreateRequestModelInputOverridesValue,
        McpToolConfigOverrideCreateRequestModelInputOverridesValue_Constant,
        McpToolConfigOverrideCreateRequestModelInputOverridesValue_DynamicVariable,
        McpToolConfigOverrideCreateRequestModelInputOverridesValue_Llm,
        McpToolConfigOverrideCreateRequestModelInputOverridesValue_Omit,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Constant,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue_DynamicVariable,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Llm,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Omit,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "McpServerConfigUpdateRequestModelAuthConnection": ".types",
    "McpServerConfigUpdateRequestModelRequestHeadersValue": ".types",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue": ".tool_configs",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Constant": ".tool_configs",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_DynamicVariable": ".tool_configs",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Llm": ".tool_configs",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Omit": ".tool_configs",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue": ".tool_configs",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Constant": ".tool_configs",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_DynamicVariable": ".tool_configs",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Llm": ".tool_configs",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Omit": ".tool_configs",
    "approval_policy": ".approval_policy",
    "tool_approvals": ".tool_approvals",
    "tool_configs": ".tool_configs",
    "tools": ".tools",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "McpServerConfigUpdateRequestModelAuthConnection",
    "McpServerConfigUpdateRequestModelRequestHeadersValue",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Constant",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_DynamicVariable",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Llm",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Omit",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Constant",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_DynamicVariable",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Llm",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Omit",
    "approval_policy",
    "tool_approvals",
    "tool_configs",
    "tools",
]
