# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.conv_ai_dynamic_variable import ConvAiDynamicVariable
from ....types.conv_ai_env_var_locator import ConvAiEnvVarLocator
from ....types.conv_ai_secret_locator import ConvAiSecretLocator

McpServerConfigUpdateRequestModelRequestHeadersValue = typing.Union[
    str, ConvAiSecretLocator, ConvAiDynamicVariable, ConvAiEnvVarLocator
]
