# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from .open_aimcp_tool_require_approval import OpenAimcpToolRequireApproval


class OpenAiSessionConfigToolsItem_Function(UncheckedBaseModel):
    type: typing.Literal["function"] = "function"
    name: str
    description: typing.Optional[str] = None
    parameters: typing.Optional[typing.Dict[str, typing.Any]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class OpenAiSessionConfigToolsItem_Mcp(UncheckedBaseModel):
    type: typing.Literal["mcp"] = "mcp"
    server_label: str
    server_url: str
    authorization: typing.Optional[str] = None
    allowed_tools: typing.Optional[typing.List[str]] = None
    require_approval: typing.Optional[OpenAimcpToolRequireApproval] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


OpenAiSessionConfigToolsItem = typing_extensions.Annotated[
    typing.Union[OpenAiSessionConfigToolsItem_Function, OpenAiSessionConfigToolsItem_Mcp],
    UnionMetadata(discriminant="type"),
]
