# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.environment_variable_response import EnvironmentVariableResponse
from ..types.environment_variables_list_response import EnvironmentVariablesListResponse
from .raw_client import AsyncRawEnvironmentVariablesClient, RawEnvironmentVariablesClient
from .types.environment_variables_create_request_body import EnvironmentVariablesCreateRequestBody
from .types.environment_variables_list_request_type import EnvironmentVariablesListRequestType
from .types.update_environment_variable_request_values_value import UpdateEnvironmentVariableRequestValuesValue

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class EnvironmentVariablesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawEnvironmentVariablesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawEnvironmentVariablesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawEnvironmentVariablesClient
        """
        return self._raw_client

    def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        label: typing.Optional[str] = None,
        environment: typing.Optional[str] = None,
        type: typing.Optional[EnvironmentVariablesListRequestType] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EnvironmentVariablesListResponse:
        """
        List all environment variables for the workspace with optional filtering

        Parameters
        ----------
        cursor : typing.Optional[str]
            Pagination cursor from previous response

        page_size : typing.Optional[int]
            Number of items to return (1-100)

        label : typing.Optional[str]
            Filter by exact label match

        environment : typing.Optional[str]
            Filter to only return variables that have this environment. When specified, the values dict in the response will only contain this environment.

        type : typing.Optional[EnvironmentVariablesListRequestType]
            Filter by variable type

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EnvironmentVariablesListResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.environment_variables.list(
            cursor="cursor",
            page_size=1,
            label="label",
            environment="environment",
            type="string",
        )
        """
        _response = self._raw_client.list(
            cursor=cursor,
            page_size=page_size,
            label=label,
            environment=environment,
            type=type,
            request_options=request_options,
        )
        return _response.data

    def create(
        self, *, request: EnvironmentVariablesCreateRequestBody, request_options: typing.Optional[RequestOptions] = None
    ) -> EnvironmentVariableResponse:
        """
        Create a new environment variable for the workspace

        Parameters
        ----------
        request : EnvironmentVariablesCreateRequestBody

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EnvironmentVariableResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs
        from elevenlabs.environment_variables import (
            EnvironmentVariablesCreateRequestBody_String,
        )

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.environment_variables.create(
            request=EnvironmentVariablesCreateRequestBody_String(
                label="label",
                values={"key": "value"},
            ),
        )
        """
        _response = self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    def get(
        self, env_var_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> EnvironmentVariableResponse:
        """
        Get a specific environment variable by ID

        Parameters
        ----------
        env_var_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EnvironmentVariableResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.environment_variables.get(
            env_var_id="env_var_id",
        )
        """
        _response = self._raw_client.get(env_var_id, request_options=request_options)
        return _response.data

    def update(
        self,
        env_var_id: str,
        *,
        values: typing.Dict[str, typing.Optional[UpdateEnvironmentVariableRequestValuesValue]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EnvironmentVariableResponse:
        """
        Replace an environment variable's values. Use null to remove an environment (except production).

        Parameters
        ----------
        env_var_id : str

        values : typing.Dict[str, typing.Optional[UpdateEnvironmentVariableRequestValuesValue]]
            Values to replace. Set to null to remove an environment (except 'production').

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EnvironmentVariableResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.environment_variables.update(
            env_var_id="env_var_id",
            values={},
        )
        """
        _response = self._raw_client.update(env_var_id, values=values, request_options=request_options)
        return _response.data


class AsyncEnvironmentVariablesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawEnvironmentVariablesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawEnvironmentVariablesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawEnvironmentVariablesClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        label: typing.Optional[str] = None,
        environment: typing.Optional[str] = None,
        type: typing.Optional[EnvironmentVariablesListRequestType] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EnvironmentVariablesListResponse:
        """
        List all environment variables for the workspace with optional filtering

        Parameters
        ----------
        cursor : typing.Optional[str]
            Pagination cursor from previous response

        page_size : typing.Optional[int]
            Number of items to return (1-100)

        label : typing.Optional[str]
            Filter by exact label match

        environment : typing.Optional[str]
            Filter to only return variables that have this environment. When specified, the values dict in the response will only contain this environment.

        type : typing.Optional[EnvironmentVariablesListRequestType]
            Filter by variable type

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EnvironmentVariablesListResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.environment_variables.list(
                cursor="cursor",
                page_size=1,
                label="label",
                environment="environment",
                type="string",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            cursor=cursor,
            page_size=page_size,
            label=label,
            environment=environment,
            type=type,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self, *, request: EnvironmentVariablesCreateRequestBody, request_options: typing.Optional[RequestOptions] = None
    ) -> EnvironmentVariableResponse:
        """
        Create a new environment variable for the workspace

        Parameters
        ----------
        request : EnvironmentVariablesCreateRequestBody

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EnvironmentVariableResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs
        from elevenlabs.environment_variables import (
            EnvironmentVariablesCreateRequestBody_String,
        )

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.environment_variables.create(
                request=EnvironmentVariablesCreateRequestBody_String(
                    label="label",
                    values={"key": "value"},
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    async def get(
        self, env_var_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> EnvironmentVariableResponse:
        """
        Get a specific environment variable by ID

        Parameters
        ----------
        env_var_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EnvironmentVariableResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.environment_variables.get(
                env_var_id="env_var_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(env_var_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        env_var_id: str,
        *,
        values: typing.Dict[str, typing.Optional[UpdateEnvironmentVariableRequestValuesValue]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EnvironmentVariableResponse:
        """
        Replace an environment variable's values. Use null to remove an environment (except production).

        Parameters
        ----------
        env_var_id : str

        values : typing.Dict[str, typing.Optional[UpdateEnvironmentVariableRequestValuesValue]]
            Values to replace. Set to null to remove an environment (except 'production').

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EnvironmentVariableResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.environment_variables.update(
                env_var_id="env_var_id",
                values={},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(env_var_id, values=values, request_options=request_options)
        return _response.data
