# This file was auto-generated by Fern from our API Definition.

import typing

DubbingListRequestDubbingStatusesItem = typing.Union[
    typing.Literal["queued", "preparing", "dubbing", "dubbed", "failed"], typing.Any
]
