# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class ListGroupSessionsParams(UncheckedBaseModel):
    """
    List scheduled group sessions for a group service in a date range.

    Group services are scheduled in advance (e.g. yoga classes, workshops) and
    callers register against an existing session. Use this for group services;
    use ``check_service_availability`` for appointment / rental services.
    """

    smb_tool_type: typing.Optional[typing.Literal["list_group_sessions"]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
