# This file was auto-generated by Fern from our API Definition.

import typing

CustomGuardrailConfigModel = typing.Union[
    typing.Literal[
        "gemini-2.5-flash-lite",
        "gemini-2.5-flash",
        "gemini-3.1-flash-lite",
        "gemini-3.5-flash",
        "claude-haiku-4-5",
        "claude-sonnet-4-6",
        "gpt-5.4-nano",
        "gpt-5.4-mini",
    ],
    typing.Any,
]
