# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        PhoneNumbersCreateRequestBody,
        PhoneNumbersCreateRequestBody_Exotel,
        PhoneNumbersCreateRequestBody_SipTrunk,
        PhoneNumbersCreateRequestBody_Twilio,
        PhoneNumbersGetResponse,
        PhoneNumbersGetResponse_Exotel,
        PhoneNumbersGetResponse_SipTrunk,
        PhoneNumbersGetResponse_Twilio,
        PhoneNumbersListResponseItem,
        PhoneNumbersListResponseItem_Exotel,
        PhoneNumbersListResponseItem_SipTrunk,
        PhoneNumbersListResponseItem_Twilio,
        PhoneNumbersUpdateResponse,
        PhoneNumbersUpdateResponse_Exotel,
        PhoneNumbersUpdateResponse_SipTrunk,
        PhoneNumbersUpdateResponse_Twilio,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "PhoneNumbersCreateRequestBody": ".types",
    "PhoneNumbersCreateRequestBody_Exotel": ".types",
    "PhoneNumbersCreateRequestBody_SipTrunk": ".types",
    "PhoneNumbersCreateRequestBody_Twilio": ".types",
    "PhoneNumbersGetResponse": ".types",
    "PhoneNumbersGetResponse_Exotel": ".types",
    "PhoneNumbersGetResponse_SipTrunk": ".types",
    "PhoneNumbersGetResponse_Twilio": ".types",
    "PhoneNumbersListResponseItem": ".types",
    "PhoneNumbersListResponseItem_Exotel": ".types",
    "PhoneNumbersListResponseItem_SipTrunk": ".types",
    "PhoneNumbersListResponseItem_Twilio": ".types",
    "PhoneNumbersUpdateResponse": ".types",
    "PhoneNumbersUpdateResponse_Exotel": ".types",
    "PhoneNumbersUpdateResponse_SipTrunk": ".types",
    "PhoneNumbersUpdateResponse_Twilio": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "PhoneNumbersCreateRequestBody",
    "PhoneNumbersCreateRequestBody_Exotel",
    "PhoneNumbersCreateRequestBody_SipTrunk",
    "PhoneNumbersCreateRequestBody_Twilio",
    "PhoneNumbersGetResponse",
    "PhoneNumbersGetResponse_Exotel",
    "PhoneNumbersGetResponse_SipTrunk",
    "PhoneNumbersGetResponse_Twilio",
    "PhoneNumbersListResponseItem",
    "PhoneNumbersListResponseItem_Exotel",
    "PhoneNumbersListResponseItem_SipTrunk",
    "PhoneNumbersListResponseItem_Twilio",
    "PhoneNumbersUpdateResponse",
    "PhoneNumbersUpdateResponse_Exotel",
    "PhoneNumbersUpdateResponse_SipTrunk",
    "PhoneNumbersUpdateResponse_Twilio",
]
