# This file was auto-generated by Fern from our API Definition.

import typing

WidgetPlacement = typing.Union[
    typing.Literal["top-left", "top", "top-right", "bottom-left", "bottom", "bottom-right"], typing.Any
]
