# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .image_subject import ImageSubject


class ImageAnalysisResult(UncheckedBaseModel):
    title: str
    description: str
    content_type: typing.Optional[str] = None
    mood_and_style: typing.Optional[str] = None
    composition_notes: typing.Optional[str] = None
    visible_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Readable text overlaid or shown in the image, if any.
    """

    subjects: typing.Optional[typing.List[ImageSubject]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
