# This file was auto-generated by Fern from our API Definition.

import typing

OrderRequestState = typing.Union[
    typing.Literal["open", "submitted", "paid", "accepted", "rejected", "done"], typing.Any
]
