# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        TestsCreateRequestBody,
        TestsCreateRequestBody_Llm,
        TestsCreateRequestBody_Simulation,
        TestsCreateRequestBody_Tool,
        TestsGetResponse,
        TestsGetResponse_Llm,
        TestsGetResponse_Simulation,
        TestsGetResponse_Tool,
        TestsListRequestSortMode,
        TestsUpdateRequestBody,
        TestsUpdateRequestBody_Llm,
        TestsUpdateRequestBody_Simulation,
        TestsUpdateRequestBody_Tool,
        TestsUpdateResponse,
        TestsUpdateResponse_Llm,
        TestsUpdateResponse_Simulation,
        TestsUpdateResponse_Tool,
    )
    from . import folders, invocations
_dynamic_imports: typing.Dict[str, str] = {
    "TestsCreateRequestBody": ".types",
    "TestsCreateRequestBody_Llm": ".types",
    "TestsCreateRequestBody_Simulation": ".types",
    "TestsCreateRequestBody_Tool": ".types",
    "TestsGetResponse": ".types",
    "TestsGetResponse_Llm": ".types",
    "TestsGetResponse_Simulation": ".types",
    "TestsGetResponse_Tool": ".types",
    "TestsListRequestSortMode": ".types",
    "TestsUpdateRequestBody": ".types",
    "TestsUpdateRequestBody_Llm": ".types",
    "TestsUpdateRequestBody_Simulation": ".types",
    "TestsUpdateRequestBody_Tool": ".types",
    "TestsUpdateResponse": ".types",
    "TestsUpdateResponse_Llm": ".types",
    "TestsUpdateResponse_Simulation": ".types",
    "TestsUpdateResponse_Tool": ".types",
    "folders": ".folders",
    "invocations": ".invocations",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "TestsCreateRequestBody",
    "TestsCreateRequestBody_Llm",
    "TestsCreateRequestBody_Simulation",
    "TestsCreateRequestBody_Tool",
    "TestsGetResponse",
    "TestsGetResponse_Llm",
    "TestsGetResponse_Simulation",
    "TestsGetResponse_Tool",
    "TestsListRequestSortMode",
    "TestsUpdateRequestBody",
    "TestsUpdateRequestBody_Llm",
    "TestsUpdateRequestBody_Simulation",
    "TestsUpdateRequestBody_Tool",
    "TestsUpdateResponse",
    "TestsUpdateResponse_Llm",
    "TestsUpdateResponse_Simulation",
    "TestsUpdateResponse_Tool",
    "folders",
    "invocations",
]
