# This file was auto-generated by Fern from our API Definition.

import typing

PermissionType = typing.Union[
    typing.Literal[
        "text_to_speech",
        "speech_to_speech",
        "speech_to_text",
        "models_read",
        "models_write",
        "voices_read",
        "voices_write",
        "speech_history_read",
        "speech_history_write",
        "sound_generation",
        "audio_isolation",
        "voice_generation",
        "dubbing_read",
        "dubbing_write",
        "pronunciation_dictionaries_read",
        "pronunciation_dictionaries_write",
        "user_read",
        "user_write",
        "projects_read",
        "projects_write",
        "audio_native_read",
        "audio_native_write",
        "workspace_read",
        "workspace_write",
        "forced_alignment",
        "convai_read",
        "convai_write",
        "music_generation",
        "image_video_generation",
        "add_voice_from_voice_library",
        "create_instant_voice_clone",
        "create_professional_voice_clone",
        "publish_voice_to_voice_library",
        "share_voice_externally",
        "create_user_api_key",
        "workspace_analytics_full_read",
        "webhooks_write",
        "service_account_write",
        "group_members_manage",
        "workspace_members_read",
        "workspace_members_invite",
        "workspace_members_remove",
        "terms_of_service_accept",
        "audit_log_read",
        "copy_resources_cross_workspace",
    ],
    typing.Any,
]
