# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .mcp_tool_config_override_create_request_model_input_overrides_value import (
        McpToolConfigOverrideCreateRequestModelInputOverridesValue,
        McpToolConfigOverrideCreateRequestModelInputOverridesValue_Constant,
        McpToolConfigOverrideCreateRequestModelInputOverridesValue_DynamicVariable,
        McpToolConfigOverrideCreateRequestModelInputOverridesValue_Llm,
        McpToolConfigOverrideCreateRequestModelInputOverridesValue_Omit,
    )
    from .mcp_tool_config_override_update_request_model_input_overrides_value import (
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Constant,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue_DynamicVariable,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Llm,
        McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Omit,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue": ".mcp_tool_config_override_create_request_model_input_overrides_value",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Constant": ".mcp_tool_config_override_create_request_model_input_overrides_value",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_DynamicVariable": ".mcp_tool_config_override_create_request_model_input_overrides_value",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Llm": ".mcp_tool_config_override_create_request_model_input_overrides_value",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Omit": ".mcp_tool_config_override_create_request_model_input_overrides_value",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue": ".mcp_tool_config_override_update_request_model_input_overrides_value",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Constant": ".mcp_tool_config_override_update_request_model_input_overrides_value",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_DynamicVariable": ".mcp_tool_config_override_update_request_model_input_overrides_value",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Llm": ".mcp_tool_config_override_update_request_model_input_overrides_value",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Omit": ".mcp_tool_config_override_update_request_model_input_overrides_value",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Constant",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_DynamicVariable",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Llm",
    "McpToolConfigOverrideCreateRequestModelInputOverridesValue_Omit",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Constant",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_DynamicVariable",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Llm",
    "McpToolConfigOverrideUpdateRequestModelInputOverridesValue_Omit",
]
