# This file was auto-generated by Fern from our API Definition.

import typing

from .conv_ai_dynamic_variable import ConvAiDynamicVariable

ApiIntegrationWebhookOverridesRequestHeadersValue = typing.Union[str, ConvAiDynamicVariable]
