# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class PhoneNumberAgentInfo(UncheckedBaseModel):
    agent_id: str = pydantic.Field()
    """
    The ID of the agent
    """

    agent_name: str = pydantic.Field()
    """
    The name of the agent
    """

    environment: typing.Optional[str] = pydantic.Field(default=None)
    """
    Environment to use for resolving environment variables on calls to this number.
    """

    branch_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Agent branch to use for calls to this number.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
