# This file was auto-generated by Fern from our API Definition.

import typing

ConfigEntityType = typing.Union[
    typing.Literal[
        "name",
        "name.name_given",
        "name.name_family",
        "name.name_other",
        "email_address",
        "contact_number",
        "dob",
        "age",
        "religious_belief",
        "political_opinion",
        "sexual_orientation",
        "ethnicity_race",
        "marital_status",
        "occupation",
        "physical_attribute",
        "language",
        "username",
        "password",
        "url",
        "organization",
        "financial_id",
        "financial_id.payment_card",
        "financial_id.payment_card.payment_card_number",
        "financial_id.payment_card.payment_card_expiration_date",
        "financial_id.payment_card.payment_card_cvv",
        "financial_id.bank_account",
        "financial_id.bank_account.bank_account_number",
        "financial_id.bank_account.bank_routing_number",
        "financial_id.bank_account.swift_bic_code",
        "financial_id.financial_id_other",
        "location",
        "location.location_address",
        "location.location_city",
        "location.location_postal_code",
        "location.location_coordinate",
        "location.location_state",
        "location.location_country",
        "location.location_other",
        "date",
        "date_interval",
        "unique_id",
        "unique_id.government_issued_id",
        "unique_id.account_number",
        "unique_id.vehicle_id",
        "unique_id.healthcare_number",
        "unique_id.healthcare_number.medical_record_number",
        "unique_id.healthcare_number.health_plan_beneficiary_number",
        "unique_id.device_id",
        "unique_id.unique_id_other",
        "medical",
        "medical.medical_condition",
        "medical.medication",
        "medical.medical_procedure",
        "medical.medical_measurement",
        "medical.medical_other",
    ],
    typing.Any,
]
