# This file was auto-generated by Fern from our API Definition.

import typing

from .conversation_history_transcript_api_integration_webhook_tools_result_common_model_output import (
    ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelOutput,
)
from .conversation_history_transcript_other_tools_result_common_model import (
    ConversationHistoryTranscriptOtherToolsResultCommonModel,
)
from .conversation_history_transcript_system_tool_result_common_model_output import (
    ConversationHistoryTranscriptSystemToolResultCommonModelOutput,
)
from .conversation_history_transcript_workflow_tools_result_common_model_output import (
    ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput,
)

ConversationHistoryTranscriptResponseModelToolResultsItem = typing.Union[
    ConversationHistoryTranscriptOtherToolsResultCommonModel,
    ConversationHistoryTranscriptSystemToolResultCommonModelOutput,
    ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelOutput,
    ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput,
]
