# This file was auto-generated by Fern from our API Definition.

import typing

from .conv_ai_secret_locator import ConvAiSecretLocator

ConversationInitiationClientDataWebhookRequestHeadersValue = typing.Union[str, ConvAiSecretLocator]
