# This file was auto-generated by Fern from our API Definition.

import typing

from .pending_cancellation_response_model import PendingCancellationResponseModel
from .pending_subscription_switch_response_model import PendingSubscriptionSwitchResponseModel

ExtendedSubscriptionResponseModelPendingChange = typing.Union[
    PendingSubscriptionSwitchResponseModel, PendingCancellationResponseModel
]
