# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import branches, deployments, drafts, knowledge_base, link, llm_usage, summaries, versions, widget
    from .summaries import (
        SummariesGetResponseValue,
        SummariesGetResponseValue_Failure,
        SummariesGetResponseValue_Success,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "SummariesGetResponseValue": ".summaries",
    "SummariesGetResponseValue_Failure": ".summaries",
    "SummariesGetResponseValue_Success": ".summaries",
    "branches": ".branches",
    "deployments": ".deployments",
    "drafts": ".drafts",
    "knowledge_base": ".knowledge_base",
    "link": ".link",
    "llm_usage": ".llm_usage",
    "summaries": ".summaries",
    "versions": ".versions",
    "widget": ".widget",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "SummariesGetResponseValue",
    "SummariesGetResponseValue_Failure",
    "SummariesGetResponseValue_Success",
    "branches",
    "deployments",
    "drafts",
    "knowledge_base",
    "link",
    "llm_usage",
    "summaries",
    "versions",
    "widget",
]
