# This file was auto-generated by Fern from our API Definition.

import typing

BodyTextToSpeechFullWithTimestampsApplyTextNormalization = typing.Union[typing.Literal["auto", "on", "off"], typing.Any]
