# This file was auto-generated by Fern from our API Definition.

import typing

from .backup_llm_default import BackupLlmDefault
from .backup_llm_disabled import BackupLlmDisabled
from .backup_llm_override import BackupLlmOverride

PromptAgentApiModelWorkflowOverrideInputBackupLlmConfig = typing.Union[
    BackupLlmDefault, BackupLlmDisabled, BackupLlmOverride
]
