# This file was auto-generated by Fern from our API Definition.

import typing

from .astllm_node_input_prompt import AstllmNodeInputPrompt
from .astllm_node_input_value_schema import AstllmNodeInputValueSchema

AstllmNodeInput = typing.Union[AstllmNodeInputValueSchema, AstllmNodeInputPrompt]
