# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata


class ContentGuardrailOutputTriggerAction_EndCall(UncheckedBaseModel):
    type: typing.Literal["end_call"] = "end_call"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ContentGuardrailOutputTriggerAction_Retry(UncheckedBaseModel):
    type: typing.Literal["retry"] = "retry"
    feedback: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


ContentGuardrailOutputTriggerAction = typing_extensions.Annotated[
    typing.Union[ContentGuardrailOutputTriggerAction_EndCall, ContentGuardrailOutputTriggerAction_Retry],
    UnionMetadata(discriminant="type"),
]
