# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AuthConnectionsCreateRequestBody,
        AuthConnectionsCreateRequestBody_BasicAuth,
        AuthConnectionsCreateRequestBody_BearerAuth,
        AuthConnectionsCreateRequestBody_CustomHeaderAuth,
        AuthConnectionsCreateRequestBody_Mtls,
        AuthConnectionsCreateRequestBody_Oauth2ClientCredentials,
        AuthConnectionsCreateRequestBody_Oauth2Jwt,
        AuthConnectionsCreateRequestBody_PrivateKeyJwt,
        AuthConnectionsCreateResponse,
        AuthConnectionsCreateResponse_ApiIntegrationOauth2AuthCode,
        AuthConnectionsCreateResponse_ApiIntegrationOauth2CustomApp,
        AuthConnectionsCreateResponse_BasicAuth,
        AuthConnectionsCreateResponse_BearerAuth,
        AuthConnectionsCreateResponse_CustomHeaderAuth,
        AuthConnectionsCreateResponse_Mtls,
        AuthConnectionsCreateResponse_Oauth2ClientCredentials,
        AuthConnectionsCreateResponse_Oauth2Jwt,
        AuthConnectionsCreateResponse_PrivateKeyJwt,
        AuthConnectionsCreateResponse_SlackBotAuth,
        AuthConnectionsCreateResponse_UrlSecret,
        AuthConnectionsCreateResponse_WhatsappAuth,
        AuthConnectionsUpdateRequestBody,
        AuthConnectionsUpdateRequestBody_BasicAuth,
        AuthConnectionsUpdateRequestBody_Oauth2ClientCredentials,
        AuthConnectionsUpdateRequestBody_Oauth2Jwt,
        AuthConnectionsUpdateResponse,
        AuthConnectionsUpdateResponse_ApiIntegrationOauth2AuthCode,
        AuthConnectionsUpdateResponse_ApiIntegrationOauth2CustomApp,
        AuthConnectionsUpdateResponse_BasicAuth,
        AuthConnectionsUpdateResponse_BearerAuth,
        AuthConnectionsUpdateResponse_CustomHeaderAuth,
        AuthConnectionsUpdateResponse_Mtls,
        AuthConnectionsUpdateResponse_Oauth2ClientCredentials,
        AuthConnectionsUpdateResponse_Oauth2Jwt,
        AuthConnectionsUpdateResponse_PrivateKeyJwt,
        AuthConnectionsUpdateResponse_SlackBotAuth,
        AuthConnectionsUpdateResponse_UrlSecret,
        AuthConnectionsUpdateResponse_WhatsappAuth,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AuthConnectionsCreateRequestBody": ".types",
    "AuthConnectionsCreateRequestBody_BasicAuth": ".types",
    "AuthConnectionsCreateRequestBody_BearerAuth": ".types",
    "AuthConnectionsCreateRequestBody_CustomHeaderAuth": ".types",
    "AuthConnectionsCreateRequestBody_Mtls": ".types",
    "AuthConnectionsCreateRequestBody_Oauth2ClientCredentials": ".types",
    "AuthConnectionsCreateRequestBody_Oauth2Jwt": ".types",
    "AuthConnectionsCreateRequestBody_PrivateKeyJwt": ".types",
    "AuthConnectionsCreateResponse": ".types",
    "AuthConnectionsCreateResponse_ApiIntegrationOauth2AuthCode": ".types",
    "AuthConnectionsCreateResponse_ApiIntegrationOauth2CustomApp": ".types",
    "AuthConnectionsCreateResponse_BasicAuth": ".types",
    "AuthConnectionsCreateResponse_BearerAuth": ".types",
    "AuthConnectionsCreateResponse_CustomHeaderAuth": ".types",
    "AuthConnectionsCreateResponse_Mtls": ".types",
    "AuthConnectionsCreateResponse_Oauth2ClientCredentials": ".types",
    "AuthConnectionsCreateResponse_Oauth2Jwt": ".types",
    "AuthConnectionsCreateResponse_PrivateKeyJwt": ".types",
    "AuthConnectionsCreateResponse_SlackBotAuth": ".types",
    "AuthConnectionsCreateResponse_UrlSecret": ".types",
    "AuthConnectionsCreateResponse_WhatsappAuth": ".types",
    "AuthConnectionsUpdateRequestBody": ".types",
    "AuthConnectionsUpdateRequestBody_BasicAuth": ".types",
    "AuthConnectionsUpdateRequestBody_Oauth2ClientCredentials": ".types",
    "AuthConnectionsUpdateRequestBody_Oauth2Jwt": ".types",
    "AuthConnectionsUpdateResponse": ".types",
    "AuthConnectionsUpdateResponse_ApiIntegrationOauth2AuthCode": ".types",
    "AuthConnectionsUpdateResponse_ApiIntegrationOauth2CustomApp": ".types",
    "AuthConnectionsUpdateResponse_BasicAuth": ".types",
    "AuthConnectionsUpdateResponse_BearerAuth": ".types",
    "AuthConnectionsUpdateResponse_CustomHeaderAuth": ".types",
    "AuthConnectionsUpdateResponse_Mtls": ".types",
    "AuthConnectionsUpdateResponse_Oauth2ClientCredentials": ".types",
    "AuthConnectionsUpdateResponse_Oauth2Jwt": ".types",
    "AuthConnectionsUpdateResponse_PrivateKeyJwt": ".types",
    "AuthConnectionsUpdateResponse_SlackBotAuth": ".types",
    "AuthConnectionsUpdateResponse_UrlSecret": ".types",
    "AuthConnectionsUpdateResponse_WhatsappAuth": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AuthConnectionsCreateRequestBody",
    "AuthConnectionsCreateRequestBody_BasicAuth",
    "AuthConnectionsCreateRequestBody_BearerAuth",
    "AuthConnectionsCreateRequestBody_CustomHeaderAuth",
    "AuthConnectionsCreateRequestBody_Mtls",
    "AuthConnectionsCreateRequestBody_Oauth2ClientCredentials",
    "AuthConnectionsCreateRequestBody_Oauth2Jwt",
    "AuthConnectionsCreateRequestBody_PrivateKeyJwt",
    "AuthConnectionsCreateResponse",
    "AuthConnectionsCreateResponse_ApiIntegrationOauth2AuthCode",
    "AuthConnectionsCreateResponse_ApiIntegrationOauth2CustomApp",
    "AuthConnectionsCreateResponse_BasicAuth",
    "AuthConnectionsCreateResponse_BearerAuth",
    "AuthConnectionsCreateResponse_CustomHeaderAuth",
    "AuthConnectionsCreateResponse_Mtls",
    "AuthConnectionsCreateResponse_Oauth2ClientCredentials",
    "AuthConnectionsCreateResponse_Oauth2Jwt",
    "AuthConnectionsCreateResponse_PrivateKeyJwt",
    "AuthConnectionsCreateResponse_SlackBotAuth",
    "AuthConnectionsCreateResponse_UrlSecret",
    "AuthConnectionsCreateResponse_WhatsappAuth",
    "AuthConnectionsUpdateRequestBody",
    "AuthConnectionsUpdateRequestBody_BasicAuth",
    "AuthConnectionsUpdateRequestBody_Oauth2ClientCredentials",
    "AuthConnectionsUpdateRequestBody_Oauth2Jwt",
    "AuthConnectionsUpdateResponse",
    "AuthConnectionsUpdateResponse_ApiIntegrationOauth2AuthCode",
    "AuthConnectionsUpdateResponse_ApiIntegrationOauth2CustomApp",
    "AuthConnectionsUpdateResponse_BasicAuth",
    "AuthConnectionsUpdateResponse_BearerAuth",
    "AuthConnectionsUpdateResponse_CustomHeaderAuth",
    "AuthConnectionsUpdateResponse_Mtls",
    "AuthConnectionsUpdateResponse_Oauth2ClientCredentials",
    "AuthConnectionsUpdateResponse_Oauth2Jwt",
    "AuthConnectionsUpdateResponse_PrivateKeyJwt",
    "AuthConnectionsUpdateResponse_SlackBotAuth",
    "AuthConnectionsUpdateResponse_UrlSecret",
    "AuthConnectionsUpdateResponse_WhatsappAuth",
]
