# This file was auto-generated by Fern from our API Definition.

import typing

BodyComposeMusicWithADetailedResponseV1MusicDetailedPostModelId = typing.Union[
    typing.Literal["music_v1", "music_v2"], typing.Any
]
