# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .conversation_history_transcript_api_integration_webhook_tools_result_common_model_input import (
    ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelInput,
)
from .conversation_history_transcript_other_tools_result_common_model import (
    ConversationHistoryTranscriptOtherToolsResultCommonModel,
)
from .conversation_history_transcript_system_tool_result_common_model_input import (
    ConversationHistoryTranscriptSystemToolResultCommonModelInput,
)

if typing.TYPE_CHECKING:
    from .conversation_history_transcript_workflow_tools_result_common_model_input import (
        ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput,
    )
WorkflowToolNestedToolsStepModelInputResultsItem = typing.Union[
    ConversationHistoryTranscriptOtherToolsResultCommonModel,
    ConversationHistoryTranscriptSystemToolResultCommonModelInput,
    ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelInput,
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput",
]
