# This file was auto-generated by Fern from our API Definition.

import typing

CreatePrivateKeyJwtRequestAlgorithm = typing.Union[
    typing.Literal["HS256", "HS384", "HS512", "RS256", "RS384", "RS512"], typing.Any
]
