# This file was auto-generated by Fern from our API Definition.

import typing

ToolType = typing.Union[
    typing.Literal[
        "system", "webhook", "client", "mcp", "workflow", "api_integration_webhook", "api_integration_mcp", "smb"
    ],
    typing.Any,
]
