# This file was auto-generated by Fern from our API Definition.

import typing

WorkspaceResourceType = typing.Union[
    typing.Literal[
        "voice",
        "voice_collection",
        "pronunciation_dictionary",
        "dubbing",
        "project",
        "convai_agents",
        "convai_knowledge_base_documents",
        "convai_tools",
        "convai_settings",
        "convai_secrets",
        "workspace_auth_connections",
        "convai_phone_numbers",
        "convai_mcp_servers",
        "convai_api_integration_connections",
        "convai_api_integration_trigger_connections",
        "convai_batch_calls",
        "convai_agent_response_tests",
        "convai_test_suite_invocations",
        "convai_crawl_jobs",
        "convai_crawl_tasks",
        "convai_whatsapp_accounts",
        "convai_agent_versions",
        "convai_agent_branches",
        "convai_agent_versions_deployments",
        "convai_memory_entries",
        "convai_coaching_proposals",
        "convai_templates",
        "dashboard",
        "dashboard_configuration",
        "convai_agent_drafts",
        "resource_locators",
        "assets",
        "content_generations",
        "content_templates",
        "songs",
        "transcription_tasks",
        "avatars",
        "avatar_video_generations",
        "resource_collection",
        "studio_projects",
    ],
    typing.Any,
]
