# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class WebhookHmacSettings(UncheckedBaseModel):
    """
    Settings for creating an HMAC-authenticated webhook
    """

    auth_type: typing.Literal["hmac"] = pydantic.Field(default="hmac")
    """
    The authentication type for this webhook
    """

    name: str = pydantic.Field()
    """
    The display name for this webhook
    """

    webhook_url: str = pydantic.Field()
    """
    The HTTPS callback URL that will be called when this webhook is triggered
    """

    request_headers: typing.Optional[typing.Dict[str, typing.Optional[str]]] = pydantic.Field(default=None)
    """
    Optional custom request headers to include with each webhook delivery
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
