# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .detailed_music_response import DetailedMusicResponse


class MultipartMusicResponse(UncheckedBaseModel):
    """
    Multipart response structure with JSON metadata and binary audio
    """

    metadata: DetailedMusicResponse = pydantic.Field()
    """
    JSON metadata about the generated audio
    """

    audio: str = pydantic.Field()
    """
    Binary audio data in the requested format
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
