# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .media_id import MediaId


class OrderMediaResponse(UncheckedBaseModel):
    media_id: MediaId = pydantic.Field()
    """
    The ID of the media file.
    """

    name: str = pydantic.Field()
    """
    The original filename of the uploaded media.
    """

    content_type: str = pydantic.Field()
    """
    The MIME type of the media file (e.g. 'video/mp4').
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    The detected or declared language of the media, if available.
    """

    signed_url: str = pydantic.Field()
    """
    A time-limited URL to download the media file.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
