# This file was auto-generated by Fern from our API Definition.

import typing

StartProcedureToolErrorStatus = typing.Union[typing.Literal["not_found", "invalid_name", "already_active"], typing.Any]
