# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .telephony_direction import TelephonyDirection


class ConversationHistorySipTrunkingPhoneCallModel(UncheckedBaseModel):
    direction: TelephonyDirection
    phone_number_id: str
    agent_number: str
    external_number: str
    call_id: typing.Optional[str] = None
    call_sid: str
    sip_header_dynamic_variables: typing.Optional[typing.Dict[str, str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
