# This file was auto-generated by Fern from our API Definition.

import typing

ClipAnimationEnterEffect = typing.Union[
    typing.Literal[
        "none",
        "fade",
        "float",
        "gentle_float",
        "zoom_in",
        "drop",
        "slide_left",
        "slide_right",
        "slide_up",
        "slide_down",
        "pop",
        "bounce",
        "spin",
        "slide_bounce",
    ],
    typing.Any,
]
