# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .auth_connection_dependencies import AuthConnectionDependencies


class CustomHeaderAuthResponse(UncheckedBaseModel):
    """
    Response model for Custom Header Auth auth connections
    """

    name: str
    provider: str
    header_name: str = pydantic.Field()
    """
    The name of the header to use for authentication (e.g., 'x-api-key')
    """

    id: str
    used_by: typing.Optional[AuthConnectionDependencies] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
