# This file was auto-generated by Fern from our API Definition.

import typing

VoiceResponseModelSafetyControl = typing.Union[
    typing.Literal["NONE", "BAN", "CAPTCHA", "ENTERPRISE_BAN", "ENTERPRISE_CAPTCHA"], typing.Any
]
