# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class AudioIsolationHistoryItemResponseModel(UncheckedBaseModel):
    id: str
    title: typing.Optional[str] = None
    created_at_unix: int
    format: str
    duration_seconds: typing.Optional[float] = None
    download_url: typing.Optional[str] = None
    icon_url: typing.Optional[str] = None
    source_video_url: typing.Optional[str] = None
    supports_video: bool
    processing: bool
    video_processing_failed: bool
    preview_b_64: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="preview_b64")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
