# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .test_run_status import TestRunStatus


class TestRunResultBucket(UncheckedBaseModel):
    test_run_ids: typing.List[str]
    title: str = pydantic.Field()
    """
    Short one-line title for this bucket
    """

    reason: str = pydantic.Field()
    """
    Short summary of why the test runs in this bucket passed or failed
    """

    status: TestRunStatus

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
