# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.rtt_end_of_stream_payload import RttEndOfStreamPayload
from ...types.rtt_input_audio_chunk_payload import RttInputAudioChunkPayload

SendRttMessage = typing.Union[RttInputAudioChunkPayload, RttEndOfStreamPayload]
