# This file was auto-generated by Fern from our API Definition.

import typing

from .open_ai_tool_choice_function import OpenAiToolChoiceFunction

OpenAiSessionConfigToolChoice = typing.Union[str, OpenAiToolChoiceFunction]
