# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.dubbing_transcript_response_model import DubbingTranscriptResponseModel

TranscriptGetTranscriptForDubResponse = typing.Union[DubbingTranscriptResponseModel, str]
