# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .cue_options_request import CueOptionsRequest
from .media_id import MediaId


class SubtitleOrderItemRequest(UncheckedBaseModel):
    media_ids: typing.List[MediaId] = pydantic.Field()
    """
    The IDs of the uploaded media files to generate subtitles for.
    """

    source_language: str = pydantic.Field()
    """
    The language code of the source media (e.g. 'en', 'es').
    """

    destination_languages: typing.List[str] = pydantic.Field()
    """
    List of target language codes. Subtitles will be generated for each media file in each destination language.
    """

    cue_options: typing.Optional[CueOptionsRequest] = pydantic.Field(default=None)
    """
    Formatting options for subtitle cues such as duration, line count, and character limits.
    """

    sdh: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether subtitles should use SDH format, which includes descriptions for deaf and hard-of-hearing viewers.
    """

    instructions: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional free-text instructions for the subtitling team.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
