# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .auth_connection_dependencies import AuthConnectionDependencies


class OAuth2ClientCredsResponse(UncheckedBaseModel):
    """
    Response model for oauth2 client creds
    """

    name: str
    provider: str
    client_id: str
    token_url: str
    scopes: typing.Optional[typing.List[str]] = None
    extra_params: typing.Optional[typing.Dict[str, str]] = None
    basic_auth_in_header: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If True, send client credentials in Authorization header as Basic Auth instead of request body
    """

    id: str
    used_by: typing.Optional[AuthConnectionDependencies] = None
    custom_headers: typing.Optional[typing.Dict[str, str]] = pydantic.Field(default=None)
    """
    Custom headers configured for OAuth2 token requests
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
