# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .conversation_history_transcript_tool_call_webhook_details import (
    ConversationHistoryTranscriptToolCallWebhookDetails,
)


class ConversationHistoryTranscriptToolCallApiIntegrationWebhookDetailsInput(UncheckedBaseModel):
    integration_id: typing.Optional[str] = None
    credential_id: typing.Optional[str] = None
    integration_connection_id: typing.Optional[str] = None
    webhook_details: ConversationHistoryTranscriptToolCallWebhookDetails

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
