# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from .....core.pydantic_utilities import IS_PYDANTIC_V2
from .....core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from .....types.agent_summary_response_model import AgentSummaryResponseModel


class SummariesGetResponseValue_Success(UncheckedBaseModel):
    status: typing.Literal["success"] = "success"
    data: AgentSummaryResponseModel

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class SummariesGetResponseValue_Failure(UncheckedBaseModel):
    status: typing.Literal["failure"] = "failure"
    error_code: int
    error_status: str
    error_message: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


SummariesGetResponseValue = typing_extensions.Annotated[
    typing.Union[SummariesGetResponseValue_Success, SummariesGetResponseValue_Failure],
    UnionMetadata(discriminant="status"),
]
