# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .environment_variables_create_request_body import (
        EnvironmentVariablesCreateRequestBody,
        EnvironmentVariablesCreateRequestBody_AuthConnection,
        EnvironmentVariablesCreateRequestBody_Secret,
        EnvironmentVariablesCreateRequestBody_String,
    )
    from .environment_variables_list_request_type import EnvironmentVariablesListRequestType
    from .update_environment_variable_request_values_value import UpdateEnvironmentVariableRequestValuesValue
_dynamic_imports: typing.Dict[str, str] = {
    "EnvironmentVariablesCreateRequestBody": ".environment_variables_create_request_body",
    "EnvironmentVariablesCreateRequestBody_AuthConnection": ".environment_variables_create_request_body",
    "EnvironmentVariablesCreateRequestBody_Secret": ".environment_variables_create_request_body",
    "EnvironmentVariablesCreateRequestBody_String": ".environment_variables_create_request_body",
    "EnvironmentVariablesListRequestType": ".environment_variables_list_request_type",
    "UpdateEnvironmentVariableRequestValuesValue": ".update_environment_variable_request_values_value",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "EnvironmentVariablesCreateRequestBody",
    "EnvironmentVariablesCreateRequestBody_AuthConnection",
    "EnvironmentVariablesCreateRequestBody_Secret",
    "EnvironmentVariablesCreateRequestBody_String",
    "EnvironmentVariablesListRequestType",
    "UpdateEnvironmentVariableRequestValuesValue",
]
