# This file was auto-generated by Fern from our API Definition.

import typing

DubbingListRequestCreationSourcesItem = typing.Union[
    typing.Literal["flow_node", "dubbing_ui", "dubbing_api"], typing.Any
]
