# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .review_response_model_reject_reasons_item import ReviewResponseModelRejectReasonsItem
from .review_response_model_review_status import ReviewResponseModelReviewStatus


class ReviewResponseModel(UncheckedBaseModel):
    review_status: ReviewResponseModelReviewStatus
    reviewed_at_unix: int
    reviewed_by: typing.Optional[str] = None
    reject_reasons: typing.Optional[typing.List[ReviewResponseModelRejectReasonsItem]] = None
    scores_breakdown: typing.Optional[typing.Dict[str, typing.Optional[int]]] = None
    rejected_details: typing.Optional[str] = None
    explanation: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
