# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.auth_connection_locator import AuthConnectionLocator
from ....types.environment_auth_connection_locator import EnvironmentAuthConnectionLocator

McpServerConfigUpdateRequestModelAuthConnection = typing.Union[AuthConnectionLocator, EnvironmentAuthConnectionLocator]
