# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .conversation_history_transcript_common_model_output import ConversationHistoryTranscriptCommonModelOutput
from .test_condition_result_common_model import TestConditionResultCommonModel
from .test_run_metadata import TestRunMetadata
from .test_run_status import TestRunStatus
from .unit_test_run_response_model_test_info import UnitTestRunResponseModelTestInfo


class UnitTestRunResponseModel(UncheckedBaseModel):
    test_run_id: str
    test_info: typing.Optional[UnitTestRunResponseModelTestInfo] = None
    test_invocation_id: str
    agent_id: str
    branch_id: typing.Optional[str] = None
    workflow_node_id: typing.Optional[str] = None
    status: TestRunStatus
    agent_responses: typing.Optional[typing.List[ConversationHistoryTranscriptCommonModelOutput]] = None
    test_id: str
    test_name: typing.Optional[str] = None
    condition_result: typing.Optional[TestConditionResultCommonModel] = None
    last_updated_at_unix: typing.Optional[int] = None
    metadata: typing.Optional[TestRunMetadata] = None
    root_folder_id: typing.Optional[str] = None
    root_folder_name: typing.Optional[str] = None
    environment: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(UnitTestRunResponseModel)
