# This file was auto-generated by Fern from our API Definition.

import typing

from .environment_variable_auth_connection_value import EnvironmentVariableAuthConnectionValue
from .environment_variable_secret_value import EnvironmentVariableSecretValue

EnvironmentVariableResponseValues = typing.Union[
    typing.Dict[str, str],
    typing.Dict[str, EnvironmentVariableSecretValue],
    typing.Dict[str, EnvironmentVariableAuthConnectionValue],
]
