# This file was auto-generated by Fern from our API Definition.

import typing

BodyGetWorkspaceUsageV1WorkspaceAnalyticsQueryUsageByProductOverTimePostGroupByItem = typing.Union[
    typing.Literal[
        "product_type",
        "model",
        "voice_id",
        "user_id",
        "fiat_currency",
        "fiat_charge_type",
        "region",
        "reporting_workspace_id",
        "request_source",
        "resource_id",
        "subresource_id",
        "request_queue_type",
        "voice_multiplier",
        "hashed_xi_api_key",
        "billing_group_id",
    ],
    typing.Any,
]
