# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .content_guardrail_output import ContentGuardrailOutput
from .custom_guardrail_output import CustomGuardrailOutput
from .focus_guardrail import FocusGuardrail
from .prompt_injection_guardrail import PromptInjectionGuardrail


class GuardrailsV1Output(UncheckedBaseModel):
    version: typing.Optional[typing.Literal["1"]] = None
    focus: typing.Optional[FocusGuardrail] = None
    prompt_injection: typing.Optional[PromptInjectionGuardrail] = None
    content: typing.Optional[ContentGuardrailOutput] = None
    custom: typing.Optional[CustomGuardrailOutput] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
