# This file was auto-generated by Fern from our API Definition.

import typing

AudioFormatEnum = typing.Union[
    typing.Literal["pcm_8000", "pcm_16000", "pcm_22050", "pcm_24000", "pcm_44100", "pcm_48000", "ulaw_8000"], typing.Any
]
