# This file was auto-generated by Fern from our API Definition.

import typing

from .constant_schema_override_constant_value_four_item import ConstantSchemaOverrideConstantValueFourItem

ConstantSchemaOverrideConstantValue = typing.Union[
    str, int, float, bool, typing.List[ConstantSchemaOverrideConstantValueFourItem]
]
