# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.rtt_audio_payload import RttAudioPayload
from ...types.rtt_error_payload import RttErrorPayload
from ...types.rtt_final_transcript_payload import RttFinalTranscriptPayload
from ...types.rtt_partial_transcript_payload import RttPartialTranscriptPayload
from ...types.rtt_session_started_payload import RttSessionStartedPayload
from ...types.rtt_status_payload import RttStatusPayload
from ...types.rtt_translation_payload import RttTranslationPayload

ReceiveRttMessage = typing.Union[
    RttSessionStartedPayload,
    RttStatusPayload,
    RttPartialTranscriptPayload,
    RttFinalTranscriptPayload,
    RttTranslationPayload,
    RttAudioPayload,
    RttErrorPayload,
]
