# This file was auto-generated by Fern from our API Definition.

import typing

from .dynamic_variable_nested_value_type_input import DynamicVariableNestedValueTypeInput

DynamicVariableValueTypeInput = typing.Union[str, float, int, bool, typing.List[DynamicVariableNestedValueTypeInput]]
