# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .referenced_tool_common_model import ReferencedToolCommonModel
from .unit_test_tool_call_parameter import UnitTestToolCallParameter
from .unit_test_workflow_node_transition_evaluation_node_id import UnitTestWorkflowNodeTransitionEvaluationNodeId


class UnitTestToolCallEvaluationModelOutput(UncheckedBaseModel):
    parameters: typing.Optional[typing.List[UnitTestToolCallParameter]] = pydantic.Field(default=None)
    """
    Parameters to evaluate for the agent's tool call. If empty, the tool call parameters are not evaluated.
    """

    referenced_tool: typing.Optional[ReferencedToolCommonModel] = pydantic.Field(default=None)
    """
    The tool to evaluate a call against.
    """

    verify_absence: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to verify that the tool was NOT called.
    """

    workflow_node_transition: typing.Optional[UnitTestWorkflowNodeTransitionEvaluationNodeId] = pydantic.Field(
        default=None
    )
    """
    Configuration for testing workflow node transitions. When set, the test will verify the agent transitions to the specified workflow node.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
