# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .dubbing_create_request_mode import DubbingCreateRequestMode
    from .dubbing_list_request_creation_sources_item import DubbingListRequestCreationSourcesItem
    from .dubbing_list_request_dubbing_models_item import DubbingListRequestDubbingModelsItem
    from .dubbing_list_request_dubbing_status import DubbingListRequestDubbingStatus
    from .dubbing_list_request_dubbing_statuses_item import DubbingListRequestDubbingStatusesItem
    from .dubbing_list_request_filter_by_creator import DubbingListRequestFilterByCreator
    from .dubbing_list_request_order_by import DubbingListRequestOrderBy
    from .dubbing_list_request_order_direction import DubbingListRequestOrderDirection
_dynamic_imports: typing.Dict[str, str] = {
    "DubbingCreateRequestMode": ".dubbing_create_request_mode",
    "DubbingListRequestCreationSourcesItem": ".dubbing_list_request_creation_sources_item",
    "DubbingListRequestDubbingModelsItem": ".dubbing_list_request_dubbing_models_item",
    "DubbingListRequestDubbingStatus": ".dubbing_list_request_dubbing_status",
    "DubbingListRequestDubbingStatusesItem": ".dubbing_list_request_dubbing_statuses_item",
    "DubbingListRequestFilterByCreator": ".dubbing_list_request_filter_by_creator",
    "DubbingListRequestOrderBy": ".dubbing_list_request_order_by",
    "DubbingListRequestOrderDirection": ".dubbing_list_request_order_direction",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "DubbingCreateRequestMode",
    "DubbingListRequestCreationSourcesItem",
    "DubbingListRequestDubbingModelsItem",
    "DubbingListRequestDubbingStatus",
    "DubbingListRequestDubbingStatusesItem",
    "DubbingListRequestFilterByCreator",
    "DubbingListRequestOrderBy",
    "DubbingListRequestOrderDirection",
]
