# This file was auto-generated by Fern from our API Definition.

import typing

MusicOnlyOutputFormats = typing.Union[
    typing.Literal["mp3_48000_128", "mp3_48000_192", "mp3_48000_240", "mp3_48000_320"], typing.Any
]
