# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.close_connection import CloseConnection
from ...types.initialize_connection import InitializeConnection
from ...types.send_text import SendText

SendMessage = typing.Union[InitializeConnection, SendText, CloseConnection]
