# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .create_private_key_jwt_request_algorithm import CreatePrivateKeyJwtRequestAlgorithm


class CreatePrivateKeyJwtRequest(UncheckedBaseModel):
    """
    Request model for creating Private Key JWT auth connections - inherits common settings and includes sensitive fields
    """

    name: str
    provider: str
    algorithm: typing.Optional[CreatePrivateKeyJwtRequestAlgorithm] = pydantic.Field(default=None)
    """
    JWT signing algorithm
    """

    key_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Key ID (kid) for JWT header - useful for key rotation
    """

    issuer: str = pydantic.Field()
    """
    JWT issuer (iss claim)
    """

    audience: str = pydantic.Field()
    """
    JWT audience (aud claim)
    """

    subject: str = pydantic.Field()
    """
    JWT subject (sub claim)
    """

    expiration_seconds: typing.Optional[int] = pydantic.Field(default=None)
    """
    Token expiration time in seconds
    """

    extra_params: typing.Optional[typing.Dict[str, str]] = pydantic.Field(default=None)
    """
    Additional custom claims to include in the JWT
    """

    secret_key: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
