# This file was auto-generated by Fern from our API Definition.

import typing

DirectPublishingReadResponseModelDisplayMode = typing.Union[
    typing.Literal["text", "audio-only", "text-with-audio"], typing.Any
]
