# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .auth_connection_dependencies_mcp_servers_item import AuthConnectionDependenciesMcpServersItem
from .auth_connection_dependencies_tools_item import AuthConnectionDependenciesToolsItem
from .dependent_integration_connection_identifier import DependentIntegrationConnectionIdentifier


class AuthConnectionDependencies(UncheckedBaseModel):
    """
    Dependencies that use an auth connection
    """

    tools: typing.Optional[typing.List[AuthConnectionDependenciesToolsItem]] = None
    mcp_servers: typing.Optional[typing.List[AuthConnectionDependenciesMcpServersItem]] = None
    integration_connections: typing.Optional[typing.List[DependentIntegrationConnectionIdentifier]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
