# This file was auto-generated by Fern from our API Definition.

import typing

RenderType = typing.Union[
    typing.Literal["mp4", "aac", "mp3", "wav", "aaf", "tracks_zip", "clips_zip", "zip"], typing.Any
]
