# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        BodyComposeMusicV1MusicPostCompositionPlan,
        BodyComposeMusicV1MusicPostModelId,
        BodyComposeMusicWithADetailedResponseV1MusicDetailedPostCompositionPlan,
        BodyComposeMusicWithADetailedResponseV1MusicDetailedPostModelId,
        BodyStreamComposedMusicV1MusicStreamPostCompositionPlan,
        BodyStreamComposedMusicV1MusicStreamPostModelId,
        MusicComposeDetailedRequestOutputFormat,
        MusicComposeRequestOutputFormat,
        MusicSeparateStemsRequestStemVariationId,
        MusicStreamRequestOutputFormat,
        MusicVideoToMusicRequestModelId,
    )
    from . import composition_plan
    from .composition_plan import (
        BodyGenerateCompositionPlanV1MusicPlanPostModelId,
        BodyGenerateCompositionPlanV1MusicPlanPostSourceCompositionPlan,
        CompositionPlanCreateResponse,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BodyComposeMusicV1MusicPostCompositionPlan": ".types",
    "BodyComposeMusicV1MusicPostModelId": ".types",
    "BodyComposeMusicWithADetailedResponseV1MusicDetailedPostCompositionPlan": ".types",
    "BodyComposeMusicWithADetailedResponseV1MusicDetailedPostModelId": ".types",
    "BodyGenerateCompositionPlanV1MusicPlanPostModelId": ".composition_plan",
    "BodyGenerateCompositionPlanV1MusicPlanPostSourceCompositionPlan": ".composition_plan",
    "BodyStreamComposedMusicV1MusicStreamPostCompositionPlan": ".types",
    "BodyStreamComposedMusicV1MusicStreamPostModelId": ".types",
    "CompositionPlanCreateResponse": ".composition_plan",
    "MusicComposeDetailedRequestOutputFormat": ".types",
    "MusicComposeRequestOutputFormat": ".types",
    "MusicSeparateStemsRequestStemVariationId": ".types",
    "MusicStreamRequestOutputFormat": ".types",
    "MusicVideoToMusicRequestModelId": ".types",
    "composition_plan": ".composition_plan",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BodyComposeMusicV1MusicPostCompositionPlan",
    "BodyComposeMusicV1MusicPostModelId",
    "BodyComposeMusicWithADetailedResponseV1MusicDetailedPostCompositionPlan",
    "BodyComposeMusicWithADetailedResponseV1MusicDetailedPostModelId",
    "BodyGenerateCompositionPlanV1MusicPlanPostModelId",
    "BodyGenerateCompositionPlanV1MusicPlanPostSourceCompositionPlan",
    "BodyStreamComposedMusicV1MusicStreamPostCompositionPlan",
    "BodyStreamComposedMusicV1MusicStreamPostModelId",
    "CompositionPlanCreateResponse",
    "MusicComposeDetailedRequestOutputFormat",
    "MusicComposeRequestOutputFormat",
    "MusicSeparateStemsRequestStemVariationId",
    "MusicStreamRequestOutputFormat",
    "MusicVideoToMusicRequestModelId",
    "composition_plan",
]
