# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .user_type_id import UserTypeId


class UserModel(UncheckedBaseModel):
    """
    OCSF User object.

    Spec: https://schema.ocsf.io/1.6.0/objects/user
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Username
    """

    uid: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique user identifier
    """

    type_id: typing.Optional[UserTypeId] = pydantic.Field(default=None)
    """
    Account type identifier
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Account type description
    """

    email_addr: typing.Optional[str] = pydantic.Field(default=None)
    """
    User email address
    """

    full_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Full name of the user
    """

    domain: typing.Optional[str] = pydantic.Field(default=None)
    """
    User's domain
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
