# This file was auto-generated by Fern from our API Definition.

import typing

SpeechHistoryItemResponseModelSource = typing.Union[
    typing.Literal[
        "TTS", "STS", "Projects", "PD", "AN", "Dubbing", "PlayAPI", "ConvAI", "VoiceGeneration", "InVPC", "Flows"
    ],
    typing.Any,
]
