# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_o_auth_2_jwt_request_algorithm import UpdateOAuth2JwtRequestAlgorithm
from .update_o_auth_2_jwt_request_token_response_field import UpdateOAuth2JwtRequestTokenResponseField


class UpdateOAuth2JwtRequest(UncheckedBaseModel):
    provider: typing.Optional[str] = None
    algorithm: typing.Optional[UpdateOAuth2JwtRequestAlgorithm] = None
    key_id: typing.Optional[str] = None
    issuer: typing.Optional[str] = None
    audience: typing.Optional[str] = None
    subject: typing.Optional[str] = None
    expiration_seconds: typing.Optional[int] = None
    extra_params: typing.Optional[typing.Dict[str, typing.Optional[str]]] = None
    scopes: typing.Optional[typing.List[str]] = None
    token_response_field: typing.Optional[UpdateOAuth2JwtRequestTokenResponseField] = None
    secret_key: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
