# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class UrlModel(UncheckedBaseModel):
    """
    OCSF URL object.

    Spec: https://schema.ocsf.io/1.6.0/objects/url
    """

    url_string: typing.Optional[str] = pydantic.Field(default=None)
    """
    Full URL string
    """

    scheme: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL scheme (e.g., https)
    """

    hostname: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL hostname
    """

    port: typing.Optional[int] = pydantic.Field(default=None)
    """
    URL port
    """

    path: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL path
    """

    query_string: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL query string
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
