# This file was auto-generated by Fern from our API Definition.

import typing

PendingSubscriptionSwitchResponseModelNextTier = typing.Union[
    typing.Literal[
        "free",
        "starter",
        "creator",
        "pro",
        "growing_business",
        "scale_2024_08_10",
        "grant_tier_1_2025_07_23",
        "grant_tier_2_2025_07_23",
        "trial",
        "enterprise",
    ],
    typing.Any,
]
