# This file was auto-generated by Fern from our API Definition.

import typing

CaptionStyleWordAnimationModelEnterType = typing.Union[
    typing.Literal["none", "fade", "scale", "pop", "slide_up", "slide_down"], typing.Any
]
