# This file was auto-generated by Fern from our API Definition.

import typing

ReviewResponseModelRejectReasonsItem = typing.Union[
    typing.Literal[
        "lacks_structure",
        "doesnt_open",
        "not_literary_work",
        "language_not_supported",
        "too_short",
        "duplicate",
        "promotional",
        "formatting_issues",
        "low_quality",
        "metadata_incomplete",
        "metadata_inaccurate",
        "typos",
        "review_error",
        "spam",
        "legal_violation",
        "content_policy",
        "public_domain",
        "other",
    ],
    typing.Any,
]
