# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class VoiceStatisticsResponseModel(UncheckedBaseModel):
    project_voice_ref_id: str = pydantic.Field()
    """
    The project voice reference ID.
    """

    characters_unconverted: int = pydantic.Field()
    """
    The number of unconverted characters for this voice.
    """

    characters_converted: int = pydantic.Field()
    """
    The number of converted characters for this voice.
    """

    credits_needed_to_convert: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of credits needed to convert the remaining audio for this voice.
    """

    voice_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The voice ID.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
