# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .billing_period import BillingPeriod
from .pending_subscription_switch_response_model_next_tier import PendingSubscriptionSwitchResponseModelNextTier


class PendingSubscriptionSwitchResponseModel(UncheckedBaseModel):
    kind: typing.Optional[typing.Literal["change"]] = None
    next_tier: PendingSubscriptionSwitchResponseModelNextTier = pydantic.Field()
    """
    The tier to change to.
    """

    next_billing_period: BillingPeriod = pydantic.Field()
    """
    The billing period to change to.
    """

    timestamp_seconds: int = pydantic.Field()
    """
    The timestamp of the change.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
