# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .transcription_word import TranscriptionWord


class CommittedTranscriptWithTimestampsPayload(UncheckedBaseModel):
    """
    Payload for committed transcription results with word-level timestamps.
    """

    message_type: typing.Literal["committed_transcript_with_timestamps"] = pydantic.Field(
        default="committed_transcript_with_timestamps"
    )
    """
    The message type identifier.
    """

    text: str = pydantic.Field()
    """
    Committed transcription text.
    """

    language_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    Detected or specified language code.
    """

    words: typing.Optional[typing.List[TranscriptionWord]] = pydantic.Field(default=None)
    """
    Word-level information with timestamps.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
