# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .knowledge_base_rag_tool_status import KnowledgeBaseRagToolStatus


class KnowledgeBaseRagToolResultModel(UncheckedBaseModel):
    status: typing.Optional[KnowledgeBaseRagToolStatus] = None
    chunk_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of relevant chunks retrieved
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Human-readable status for the LLM about the search results
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
