# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .background_sound_config_workflow_override import BackgroundSoundConfigWorkflowOverride
from .client_event import ClientEvent
from .file_input_config_workflow_override import FileInputConfigWorkflowOverride


class ConversationConfigWorkflowOverrideOutput(UncheckedBaseModel):
    text_only: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If enabled audio will not be processed and only text will be used, use to avoid audio pricing.
    """

    max_duration_seconds: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum duration of a conversation in seconds
    """

    client_events: typing.Optional[typing.List[ClientEvent]] = pydantic.Field(default=None)
    """
    The events that will be sent to the client
    """

    file_input: typing.Optional[FileInputConfigWorkflowOverride] = pydantic.Field(default=None)
    """
    Configuration for file input (image/PDF uploads) during conversations.
    """

    monitoring_enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Enable real-time monitoring of conversations via WebSocket
    """

    monitoring_events: typing.Optional[typing.List[ClientEvent]] = pydantic.Field(default=None)
    """
    The events that will be sent to monitoring connections.
    """

    background_sound: typing.Optional[BackgroundSoundConfigWorkflowOverride] = pydantic.Field(default=None)
    """
    Configuration for background sound during conversations.
    """

    source_attribution: typing.Optional[bool] = pydantic.Field(default=None)
    """
    When enabled and knowledge base content is present, the LLM is instructed to report which sources it used.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
