# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .twilio_edge_location import TwilioEdgeLocation
from .twilio_region_id import TwilioRegionId


class RegionConfigRequest(UncheckedBaseModel):
    region_id: TwilioRegionId = pydantic.Field()
    """
    Region ID
    """

    token: str = pydantic.Field()
    """
    Auth Token for this region
    """

    edge_location: TwilioEdgeLocation = pydantic.Field()
    """
    Edge location for this region
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
