# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .interaction_budget import InteractionBudget
from .output_format import OutputFormat
from .verbosity import Verbosity


class BehaviorOverride(UncheckedBaseModel):
    verbosity: typing.Optional[Verbosity] = pydantic.Field(default=None)
    """
    Verbosity override. Underlying default applies when unset.
    """

    output_format: typing.Optional[OutputFormat] = pydantic.Field(default=None)
    """
    Output format override. Underlying default applies when unset.
    """

    interaction_budget: typing.Optional[InteractionBudget] = pydantic.Field(default=None)
    """
    Interaction budget override. Underlying default applies when unset.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
