# This file was auto-generated by Fern from our API Definition.

import typing

ProjectCreationMetaResponseModelType = typing.Union[
    typing.Literal["blank", "generate_podcast", "auto_assign_voices", "dub_video", "import_speech"], typing.Any
]
