# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DeviceModel(UncheckedBaseModel):
    """
    Device information.

    Spec: https://schema.ocsf.io/1.6.0/objects/device
    """

    ip: typing.Optional[str] = pydantic.Field(default=None)
    """
    IP address
    """

    hostname: typing.Optional[str] = pydantic.Field(default=None)
    """
    Device hostname
    """

    type_id: typing.Optional[int] = pydantic.Field(default=None)
    """
    Device type ID (99 = Unknown)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
