# This file was auto-generated by Fern from our API Definition.

import typing

from .account_change_activity_id import AccountChangeActivityId
from .authentication_activity_id import AuthenticationActivityId
from .entity_management_activity_id import EntityManagementActivityId
from .group_management_activity_id import GroupManagementActivityId
from .user_access_management_activity_id import UserAccessManagementActivityId

WorkspaceAuditLogEntryResponseActivityId = typing.Union[
    AccountChangeActivityId,
    AuthenticationActivityId,
    EntityManagementActivityId,
    UserAccessManagementActivityId,
    GroupManagementActivityId,
]
