# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .resource_access_info import ResourceAccessInfo


class SpeechEngineSummaryResponse(UncheckedBaseModel):
    speech_engine_id: str = pydantic.Field()
    """
    The speech engine resource ID
    """

    name: str = pydantic.Field()
    """
    Human-readable name for the speech engine
    """

    created_at_unix_secs: int = pydantic.Field()
    """
    Creation time in Unix seconds
    """

    tags: typing.List[str] = pydantic.Field()
    """
    Arbitrary tags for categorization and filtering
    """

    access_info: ResourceAccessInfo = pydantic.Field()
    """
    The access information of the speech engine for the user
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
