# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .item_id import ItemId
from .quote_info import QuoteInfo


class UpsertOrderItemResponse(UncheckedBaseModel):
    item_id: ItemId = pydantic.Field()
    """
    The ID of the upserted order item.
    """

    quote: typing.Optional[QuoteInfo] = pydantic.Field(default=None)
    """
    The quoted price for this item.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
