# This file was auto-generated by Fern from our API Definition.

import typing

from .music_allowed_output_formats import MusicAllowedOutputFormats

MusicOutputFormat = typing.Union[MusicAllowedOutputFormats, typing.Literal["auto"]]
