# This file was auto-generated by Fern from our API Definition.

import typing

MetricType = typing.Union[
    typing.Literal[
        "credits",
        "tts_characters",
        "minutes_used",
        "request_count",
        "ttfb_avg",
        "ttfb_p95",
        "fiat_units_spent",
        "concurrency",
        "concurrency_average",
    ],
    typing.Any,
]
