# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class CustomSipHeaderWithDynamicVariable(UncheckedBaseModel):
    """
    Custom SIP header for phone transfers with a dynamic variable reference.
    The value is a variable name that will be resolved at runtime.
    Value is not validated here since it will be substituted with actual value later.
    """

    key: str = pydantic.Field()
    """
    The SIP header name (e.g., 'X-Customer-ID')
    """

    value: str = pydantic.Field()
    """
    The dynamic variable name to resolve
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
