# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .media_id import MediaId


class DubOrderItemRequest(UncheckedBaseModel):
    media_id: MediaId = pydantic.Field()
    """
    The ID of the uploaded media file to dub.
    """

    source_language: str = pydantic.Field()
    """
    The language code of the source media (e.g. 'en', 'es').
    """

    destination_languages: typing.List[str] = pydantic.Field()
    """
    List of target language codes to dub the media into.
    """

    include_captions: bool = pydantic.Field()
    """
    Whether to generate captions for the dubbed outputs.
    """

    include_source_captions: bool = pydantic.Field()
    """
    Whether to generate captions for the source language.
    """

    instructions: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional free-text instructions for the dubbing team.
    """

    captions_sdh: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether captions should use SDH format, which includes descriptions for deaf and hard-of-hearing viewers.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
