# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class LlmDeprecationConfigModel(UncheckedBaseModel):
    warning_start_days: int = pydantic.Field()
    """
    Number of days before the provider deprecation date when warnings start being shown.
    """

    fallback_start_days: int = pydantic.Field()
    """
    Number of days before the provider deprecation date when traffic starts being routed to the replacement model.
    """

    fallback_complete_days: int = pydantic.Field()
    """
    Number of days before the provider deprecation date when all traffic is routed to the replacement model.
    """

    fallback_start_percentage: int = pydantic.Field()
    """
    Percentage of traffic routed to the replacement model when fallback begins.
    """

    fallback_complete_percentage: int = pydantic.Field()
    """
    Percentage of traffic routed to the replacement model when fallback is complete.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
