# This file was auto-generated by Fern from our API Definition.

import typing

ProjectsCreateRequestSourceType = typing.Union[
    typing.Literal["blank", "book", "article", "genfm", "video", "screenplay"], typing.Any
]
