# This file was auto-generated by Fern from our API Definition.

import typing

WebhookToolApiSchemaConfigOutputContentType = typing.Union[
    typing.Literal["application/json", "application/x-www-form-urlencoded"], typing.Any
]
