# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.multichannel_speech_to_text_response_model import MultichannelSpeechToTextResponseModel
from ....types.speech_to_text_chunk_response_model import SpeechToTextChunkResponseModel

TranscriptsGetResponse = typing.Union[SpeechToTextChunkResponseModel, MultichannelSpeechToTextResponseModel]
