# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .llm_deprecation_config_model import LlmDeprecationConfigModel
from .llm_info_model_input import LlmInfoModelInput


class LlmListResponseModelInput(UncheckedBaseModel):
    llms: typing.List[LlmInfoModelInput] = pydantic.Field()
    """
    List of all available LLM models that can be used with agents.
    """

    default_deprecation_config: LlmDeprecationConfigModel = pydantic.Field()
    """
    The default deprecation timing configuration used for models without a custom override.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
