# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.environment_variable_auth_connection_value_request import EnvironmentVariableAuthConnectionValueRequest
from ...types.environment_variable_secret_value_request import EnvironmentVariableSecretValueRequest

UpdateEnvironmentVariableRequestValuesValue = typing.Union[
    str, EnvironmentVariableSecretValueRequest, EnvironmentVariableAuthConnectionValueRequest
]
