# This file was auto-generated by Fern from our API Definition.

import typing

PendingClipTaskType = typing.Union[
    typing.Literal["preprocessing", "speech_import", "dubbing", "video_to_music", "media_generation"], typing.Any
]
