# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .sample_config_db_model_parent_type import SampleConfigDbModelParentType


class SampleConfigDbModel(UncheckedBaseModel):
    is_sample: typing.Optional[bool] = None
    parent_id: typing.Optional[str] = None
    parent_type: typing.Optional[SampleConfigDbModelParentType] = None
    chapter_ids: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
