# This file was auto-generated by Fern from our API Definition.

import typing

ResourceAccessInfoAccessSource = typing.Union[
    typing.Literal["creator", "explicit", "workspace_admin", "workspace_default"], typing.Any
]
