# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ConversationsGetRequestFormat,
        ConversationsListRequestExcludeStatusesItem,
        ConversationsListRequestSummaryMode,
    )
    from . import analysis, audio, feedback, files, messages, tags, topics
    from .messages import MessagesTextSearchRequestSummaryMode
_dynamic_imports: typing.Dict[str, str] = {
    "ConversationsGetRequestFormat": ".types",
    "ConversationsListRequestExcludeStatusesItem": ".types",
    "ConversationsListRequestSummaryMode": ".types",
    "MessagesTextSearchRequestSummaryMode": ".messages",
    "analysis": ".analysis",
    "audio": ".audio",
    "feedback": ".feedback",
    "files": ".files",
    "messages": ".messages",
    "tags": ".tags",
    "topics": ".topics",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ConversationsGetRequestFormat",
    "ConversationsListRequestExcludeStatusesItem",
    "ConversationsListRequestSummaryMode",
    "MessagesTextSearchRequestSummaryMode",
    "analysis",
    "audio",
    "feedback",
    "files",
    "messages",
    "tags",
    "topics",
]
