# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class CanvasPlacement(UncheckedBaseModel):
    """
    Defines asset positioning and transformation on canvas.
    """

    x_relative: typing.Optional[float] = None
    y_relative: typing.Optional[float] = None
    scale_x: typing.Optional[float] = None
    scale_y: typing.Optional[float] = None
    pivot_x: typing.Optional[float] = None
    pivot_y: typing.Optional[float] = None
    skew_x: typing.Optional[float] = None
    skew_y: typing.Optional[float] = None
    crop_top: typing.Optional[float] = None
    crop_right: typing.Optional[float] = None
    crop_bottom: typing.Optional[float] = None
    crop_left: typing.Optional[float] = None
    flip_x: typing.Optional[bool] = None
    flip_y: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
