# This file was auto-generated by Fern from our API Definition.

import typing

VoicesGetSharedRequestSort = typing.Union[
    typing.Literal["created_date", "usage_character_count_1y", "trending", "cloned_by_count"], typing.Any
]
