# This file was auto-generated by Fern from our API Definition.

import typing

ToolCallSoundType = typing.Union[
    typing.Literal["typing", "elevator1", "elevator2", "elevator3", "elevator4"], typing.Any
]
