# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .agent_workflow_request_model_nodes_value import AgentWorkflowRequestModelNodesValue
from .workflow_edge_model_input import WorkflowEdgeModelInput


class AgentWorkflowRequestModel(UncheckedBaseModel):
    edges: typing.Optional[typing.Dict[str, WorkflowEdgeModelInput]] = None
    nodes: typing.Optional[typing.Dict[str, AgentWorkflowRequestModelNodesValue]] = None
    prevent_subagent_loops: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to prevent loops in the workflow execution.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(AgentWorkflowRequestModel)
