# This file was auto-generated by Fern from our API Definition.

import typing

from .auth_connection_locator import AuthConnectionLocator
from .environment_auth_connection_locator import EnvironmentAuthConnectionLocator

CustomLlmAuthConnection = typing.Union[AuthConnectionLocator, EnvironmentAuthConnectionLocator]
