# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .speech_engine_config_request_headers_value import SpeechEngineConfigRequestHeadersValue


class SpeechEngineConfig(UncheckedBaseModel):
    ws_url: str = pydantic.Field()
    """
    The WebSocket URL for the transcript server
    """

    request_headers: typing.Optional[typing.Dict[str, SpeechEngineConfigRequestHeadersValue]] = pydantic.Field(
        default=None
    )
    """
    Headers to include in the WebSocket connection request
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
