# This file was auto-generated by Fern from our API Definition.

import typing

from .conv_ai_env_var_locator import ConvAiEnvVarLocator
from .conv_ai_secret_locator import ConvAiSecretLocator

CustomLlmApiKey = typing.Union[ConvAiSecretLocator, ConvAiEnvVarLocator]
