# This file was auto-generated by Fern from our API Definition.

import typing

from .audio_ref_chunk import AudioRefChunk
from .generation_chunk_input import GenerationChunkInput

CompositionPlanChunksItem = typing.Union[GenerationChunkInput, AudioRefChunk]
