# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.agent_response_payload import AgentResponsePayload
from ...types.pong_payload import PongPayload

SendUpstreamMessage = typing.Union[AgentResponsePayload, PongPayload]
