# This file was auto-generated by Fern from our API Definition.

import typing

BatchCallRecipientStatus = typing.Union[
    typing.Literal[
        "pending", "dispatched", "initiated", "in_progress", "completed", "failed", "cancelled", "voicemail"
    ],
    typing.Any,
]
