# This file was auto-generated by Fern from our API Definition.

import typing

LibraryVoiceResponseModelCategory = typing.Union[
    typing.Literal["generated", "cloned", "premade", "professional", "famous", "high_quality"], typing.Any
]
