# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .agent_version_parents import AgentVersionParents
from .resource_access_info import ResourceAccessInfo


class AgentVersionMetadata(UncheckedBaseModel):
    id: str
    agent_id: str
    branch_id: str
    version_description: str
    seq_no_in_branch: int
    time_committed_secs: int
    parents: AgentVersionParents
    access_info: typing.Optional[ResourceAccessInfo] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
