# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .llm import Llm
from .llm_deprecation_info_model import LlmDeprecationInfoModel
from .llm_reasoning_effort import LlmReasoningEffort
from .regional_processing_surcharge_info import RegionalProcessingSurchargeInfo


class LlmInfoModelOutput(UncheckedBaseModel):
    llm: Llm = pydantic.Field()
    """
    The model identifier.
    """

    is_checkpoint: bool = pydantic.Field()
    """
    Whether this is a pinned checkpoint version of a model rather than a top-level alias.
    """

    max_tokens_limit: int = pydantic.Field()
    """
    Maximum number of output tokens the model can generate.
    """

    max_context_limit: int = pydantic.Field()
    """
    Maximum number of input context tokens the model supports.
    """

    supports_image_input: bool = pydantic.Field()
    """
    Whether the model supports image file inputs during conversations.
    """

    supports_document_input: bool = pydantic.Field()
    """
    Whether the model supports document (PDF) file inputs during conversations.
    """

    supports_parallel_tool_calls: bool = pydantic.Field()
    """
    Whether the model supports calling multiple tools in parallel.
    """

    available_reasoning_efforts: typing.Optional[typing.List[LlmReasoningEffort]] = pydantic.Field(default=None)
    """
    Available reasoning effort levels for this model. Null if the model does not support configurable reasoning.
    """

    deprecation_info: typing.Optional[LlmDeprecationInfoModel] = pydantic.Field(default=None)
    """
    Deprecation information if this model is deprecated or scheduled for deprecation. Null if the model is not affected.
    """

    regional_processing_surcharge: typing.Optional[RegionalProcessingSurchargeInfo] = pydantic.Field(default=None)
    """
    Regional processing surcharge details if this model has additional costs in the current deployment region. Null if no surcharge applies.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
