# This file was auto-generated by Fern from our API Definition.

import typing

from .conv_ai_secret_locator import ConvAiSecretLocator
from .conv_ai_user_secret_db_model import ConvAiUserSecretDbModel

McpServerConfigInputSecretToken = typing.Union[ConvAiSecretLocator, ConvAiUserSecretDbModel]
