# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.audio_output import AudioOutput
from ...types.final_output import FinalOutput

ReceiveMessage = typing.Union[AudioOutput, FinalOutput]
