# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .time_range import TimeRange


class AudioRefChunk(UncheckedBaseModel):
    song_id: str = pydantic.Field()
    """
    The ID of the song to source the chunk from. You can find the song ID in the response headers when you generate a song.
    """

    range: TimeRange = pydantic.Field()
    """
    The time range to extract from the song.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
