# This file was auto-generated by Fern from our API Definition.

import typing

TwilioEdgeLocation = typing.Union[
    typing.Literal[
        "ashburn", "dublin", "frankfurt", "sao-paulo", "singapore", "sydney", "tokyo", "umatilla", "roaming"
    ],
    typing.Any,
]
