# This file was auto-generated by Fern from our API Definition.

import typing

RttOutputFormatEnum = typing.Union[
    typing.Literal[
        "mp3_22050_32",
        "mp3_44100_32",
        "mp3_44100_64",
        "mp3_44100_96",
        "mp3_44100_128",
        "mp3_44100_192",
        "pcm_16000",
        "pcm_22050",
        "pcm_24000",
        "pcm_44100",
        "ulaw_8000",
    ],
    typing.Any,
]
