# This file was auto-generated by Fern from our API Definition.

import typing

McpApprovalPolicy = typing.Union[
    typing.Literal["auto_approve_all", "require_approval_all", "require_approval_per_tool"], typing.Any
]
